searchData={"items":[{"type":"module","title":"ExAws.CodePipeline","doc":"Operations on AWS CodePipeline\n\nThe documentation and types provided lean heavily on the [AWS documentation for\nCodePipeline](https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_Operations.html).\nThe AWS documentation is the definitive source of information and should be consulted to\nunderstand how to use CodePipeline and its API functions. The documentation on types and\nfunctions in the library may be helpful but it is merely helpful. It does not attempt to\nprovide an explanation for how to use CodePipeline.\n\nThe library does not try to provide protection against invalid values, length restriction\nviolations, or violations of pattern matching defined in the API documentation. There is some\nminimal checking for correct types but, generally, the data passed by the app is converted to\na JSON representation and the error will be returned by the API when it is called.\n\nGenerally the functions take required parameters separately from any optional arguments. The\noptional arguments are passed as a Map (with a defined type).\n\nThe defined types used to pass optional arguments use the standard Elixir snake-case for keys. The\nAPI itself uses camel-case Strings for keys. The library provides the conversion. Most of the API\nkeys use a lower-case letter for the first word and upper-case for the subsequent words. If there\nare exceptions to this rule they are handled by the library so an Elixir developer can just use\nstandard snake-case for all the keys.\n\nThe CodePipeline API is broad. If you find errors in this code then please submit a PR so that\nany issues I've missed can be resolved as quickly as possible.","ref":"ExAws.CodePipeline.html"},{"type":"module","title":"Description - ExAws.CodePipeline","doc":"AWS CodePipeline is a continuous delivery service you can use to model, visualize, and automate\nthe steps required to release your software. You can quickly model and configure the different\nstages of a software release process. CodePipeline automates the steps required to release your\nsoftware changes continuously.","ref":"ExAws.CodePipeline.html#module-description"},{"type":"module","title":"Resources - ExAws.CodePipeline","doc":"- [CodePipeline User Guide](https://docs.aws.amazon.com/codepipeline/latest/userguide/welcome.html)\n- [CodePipeline API Reference Guide](https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_Operations.html)\n- [CLI Reference for CodePipeline}](https://docs.aws.amazon.com/cli/latest/reference/codepipeline/index.html)","ref":"ExAws.CodePipeline.html#module-resources"},{"type":"function","title":"ExAws.CodePipeline.acknowledge_job/2","doc":"Returns information about a specified job and whether that job has been received by the job\nworker. Only used for custom actions.","ref":"ExAws.CodePipeline.html#acknowledge_job/2"},{"type":"function","title":"Examples - ExAws.CodePipeline.acknowledge_job/2","doc":"iex> job_id = \"f4f4ff82-2d11-EXAMPLE\"\n    iex> nonce = \"3\"\n    iex> ExAws.CodePipeline.acknowledge_job(job_id, nonce)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"jobId\" => \"f4f4ff82-2d11-EXAMPLE\", \"nonce\" => \"3\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.AcknowledgeJob\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#acknowledge_job/2-examples"},{"type":"function","title":"ExAws.CodePipeline.acknowledge_third_party_job/3","doc":"Confirms a job worker has received the specified job. Only used for partner actions.","ref":"ExAws.CodePipeline.html#acknowledge_third_party_job/3"},{"type":"function","title":"Examples - ExAws.CodePipeline.acknowledge_third_party_job/3","doc":"iex> job_id = \"f4f4ff82-2d11-EXAMPLE\"\n    iex> nonce = \"3\"\n    iex> ExAws.CodePipeline.acknowledge_third_party_job(\"ABCXYZ\", job_id, nonce)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"clientToken\" => \"ABCXYZ\",\n        \"jobId\" => \"f4f4ff82-2d11-EXAMPLE\",\n        \"nonce\" => \"3\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.AcknowledgeThirdPartyJob\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#acknowledge_third_party_job/3-examples"},{"type":"function","title":"ExAws.CodePipeline.create_custom_action_type/6","doc":"Creates a new custom action that can be used in all pipelines associated\nwith the AWS account\n\nOnly used for custom actions since it is not needed for the provided Pipeline actions that help\nyou configure build, test, and deploy resources for your automated release process.","ref":"ExAws.CodePipeline.html#create_custom_action_type/6"},{"type":"function","title":"Examples - ExAws.CodePipeline.create_custom_action_type/6","doc":"iex> alias ExAws.CodePipeline\n    iex> version = 1\n    iex> category = \"Build\"\n    iex> provider = \"MyJenkinsProviderName\"\n    iex> input_artifact_details = %{maximum_count: 1, minimum_count: 0}\n    iex> output_artifact_details = %{maximum_count: 1, minimum_count: 0}\n    iex> opts = %{\n    ...>  settings: %{\n    ...>    entity_url_template: \"https://192.0.2.4/job/{Config:ProjectName}/\",\n    ...>    execution_url_template: \"https://192.0.2.4/job/{Config:ProjectName}/lastSuccessfulBuild/{ExternalExecutionId}/\"\n    ...> },\n    ...> configuration_properties: [\n    ...>   %{\n    ...>      name: \"MyJenkinsExampleBuildProject\",\n    ...>      type: \"String\",\n    ...>      description: \"The name of the build project must be provided when this action is added to the pipeline.\",\n    ...>      key: true,\n    ...>      required: true,\n    ...>      secret: false,\n    ...>      queryable: false\n    ...>    }\n    ...>  ],\n    ...>  tags: [%{key: \"test\", value: \"TaggingValue\"}]\n    ...> }\n    iex> map_result = CodePipeline.create_custom_action_type(category, provider, version,\n    ...>                                                     input_artifact_details,\n    ...>                                                     output_artifact_details,\n    ...>                                                     opts)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"category\" => \"Build\",\n        \"configurationProperties\" => [\n          %{\n            \"description\" => \"The name of the build project must be provided when this action is added to the pipeline.\",\n            \"key\" => true,\n            \"name\" => \"MyJenkinsExampleBuildProject\",\n            \"queryable\" => false,\n            \"required\" => true,\n            \"secret\" => false,\n            \"type\" => \"String\"\n          }\n        ],\n        \"inputArtifactDetails\" => %{\"maximumCount\" => 1, \"minimumCount\" => 0},\n        \"outputArtifactDetails\" => %{\"maximumCount\" => 1, \"minimumCount\" => 0},\n        \"provider\" => \"MyJenkinsProviderName\",\n        \"settings\" => %{\n          \"entityUrlTemplate\" => \"https://192.0.2.4/job/{Config:ProjectName}/\",\n          \"executionUrlTemplate\" => \"https://192.0.2.4/job/{Config:ProjectName}/lastSuccessfulBuild/{ExternalExecutionId}/\"\n        },\n        \"tags\" => [\n          %{\"key\" => \"test\", \"value\" => \"TaggingValue\"}\n        ],\n        \"version\" => 1\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.CreateCustomActionType\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }\n    iex> keyword_opts = [\n    ...>  settings: [\n    ...>    entity_url_template: \"https://192.0.2.4/job/{Config:ProjectName}/\",\n    ...>    execution_url_template: \"https://192.0.2.4/job/{Config:ProjectName}/lastSuccessfulBuild/{ExternalExecutionId}/\"\n    ...>  ],\n    ...>  configuration_properties: [\n    ...>    [\n    ...>      name: \"MyJenkinsExampleBuildProject\",\n    ...>      type: \"String\",\n    ...>      description: \"The name of the build project must be provided when this action is added to the pipeline.\",\n    ...>      key: true,\n    ...>      required: true,\n    ...>      secret: false,\n    ...>      queryable: false\n    ...>    ]\n    ...>  ],\n    ...>  tags: [[key: \"test\", value: \"TaggingValue\"]]\n    ...>]\n    iex> keyword_result = CodePipeline.create_custom_action_type(category, provider, version,\n    ...>                                                         input_artifact_details,\n    ...>                                                         output_artifact_details,\n    ...>                                                         keyword_opts)\n    iex> map_result == keyword_result\n    true\n    iex> ###########################################################################\n    iex> # The above demonstrates that using Keyword or Map for input\n    iex> # does not matter. They produce the same `ExAws.Operation.JSON.t`\n    iex> ###########################################################################","ref":"ExAws.CodePipeline.html#create_custom_action_type/6-examples"},{"type":"function","title":"ExAws.CodePipeline.create_pipeline/2","doc":"Creates a pipeline\n\nThe `pipeline` argument must include either `artifact_store` or `artifact_stores`. You cannot use\nboth. If you create a cross-region action in your pipeline, you must use `artifact_stores`.","ref":"ExAws.CodePipeline.html#create_pipeline/2"},{"type":"function","title":"Examples - ExAws.CodePipeline.create_pipeline/2","doc":"The examples below demonstrate using `create_pipeline/1` with either Map data\nstructure or Keyword list. Both produce the same output.\n\n    iex> maps_pipeline_result = %{\n    ...>  role_arn: \"arn:aws:iam::111111111111:role/AWS-CodePipeline-Service\",\n    ...>  stages: [\n    ...>    %{\n    ...>      name: \"Source\",\n    ...>      actions: [\n    ...>        %{\n    ...>          name: \"Source\",\n    ...>          action_type_id: %{\n    ...>            owner: \"AWS\",\n    ...>            version: \"1\",\n    ...>            category: \"Source\",\n    ...>            provider: \"S3\"\n    ...>          },\n    ...>          configuration: %{\n    ...>            \"S3Bucket\" => \"awscodepipeline-demo-bucket\",\n    ...>            \"S3ObjectKey\" => \"aws-codepipeline-s3-aws-codedeploy_linux.zip\"\n    ...>          },\n    ...>          input_artifacts: [],\n    ...>          run_order: 1,\n    ...>          output_artifacts: [%{name: \"MyApp\"}]\n    ...>        }\n    ...>      ]\n    ...>    },\n    ...>    %{\n    ...>      name: \"MySecondPipeline\",\n    ...>      version: 1,\n    ...>      artifact_store: %{\n    ...>        type: \"S3\",\n    ...>        location: \"codepipeline-us-east-1-11EXAMPLE11\"\n    ...>      },\n    ...>      actions: [\n    ...>        %{\n    ...>          name: \"CodePipelineDemoFleet\",\n    ...>          action_type_id: %{\n    ...>            owner: \"AWS\",\n    ...>            version: \"1\",\n    ...>            category: \"Deploy\",\n    ...>            provider: \"CodeDeploy\"\n    ...>          },\n    ...>          configuration: %{\n    ...>            \"ApplicationName\" => \"CodePipelineDemoApplication\",\n    ...>            \"DeploymentGroupName\" => \"CodePipelineDemoFleet\"\n    ...>          },\n    ...>          input_artifacts: [%{name: \"MyApp\"}],\n    ...>          run_order: 1,\n    ...>          output_artifacts: []\n    ...>        }\n    ...>      ]\n    ...>    }\n    ...>  ]\n    ...>} |> ExAws.CodePipeline.create_pipeline()\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"pipeline\" => %{\n          \"roleArn\" => \"arn:aws:iam::111111111111:role/AWS-CodePipeline-Service\",\n          \"stages\" => [\n            %{\n              \"actions\" => [\n                %{\n                  \"actionTypeId\" => %{\n                    \"category\" => \"Source\",\n                    \"owner\" => \"AWS\",\n                    \"provider\" => \"S3\",\n                    \"version\" => \"1\"\n                  },\n                  \"configuration\" => %{\n                    \"S3Bucket\" => \"awscodepipeline-demo-bucket\",\n                    \"S3ObjectKey\" => \"aws-codepipeline-s3-aws-codedeploy_linux.zip\"\n                  },\n                  \"inputArtifacts\" => [],\n                  \"name\" => \"Source\",\n                  \"outputArtifacts\" => [%{\"name\" => \"MyApp\"}],\n                  \"runOrder\" => 1\n                }\n              ],\n              \"name\" => \"Source\"\n            },\n            %{\n              \"actions\" => [\n                %{\n                  \"actionTypeId\" => %{\n                    \"category\" => \"Deploy\",\n                    \"owner\" => \"AWS\",\n                    \"provider\" => \"CodeDeploy\",\n                    \"version\" => \"1\"\n                  },\n                  \"configuration\" => %{\n                    \"ApplicationName\" => \"CodePipelineDemoApplication\",\n                    \"DeploymentGroupName\" => \"CodePipelineDemoFleet\"\n                  },\n                  \"inputArtifacts\" => [%{\"name\" => \"MyApp\"}],\n                  \"name\" => \"CodePipelineDemoFleet\",\n                  \"outputArtifacts\" => [],\n                  \"runOrder\" => 1\n                }\n              ],\n              \"artifactStore\" => %{\n                \"location\" => \"codepipeline-us-east-1-11EXAMPLE11\",\n                \"type\" => \"S3\"\n              },\n              \"name\" => \"MySecondPipeline\",\n              \"version\" => 1\n            }\n          ]\n        },\n        \"tags\" => []\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.CreatePipeline\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }\n    iex> keyword_pipeline_result = [\n    ...>  role_arn: \"arn:aws:iam::111111111111:role/AWS-CodePipeline-Service\",\n    ...>  stages: [\n    ...>    [\n    ...>      name: \"Source\",\n    ...>      actions: [\n    ...>        [\n    ...>          input_artifacts: [],\n    ...>          name: \"Source\",\n    ...>          action_type_id: [\n    ...>            category: \"Source\",\n    ...>            owner: \"AWS\",\n    ...>            version: \"1\",\n    ...>            provider: \"S3\"\n    ...>          ],\n    ...>          output_artifacts: [\n    ...>            [\n    ...>              name: \"MyApp\"\n    ...>            ]\n    ...>          ],\n    ...>          configuration: %{\n    ...>            \"S3Bucket\" => \"awscodepipeline-demo-bucket\",\n    ...>            \"S3ObjectKey\" => \"aws-codepipeline-s3-aws-codedeploy_linux.zip\"\n    ...>          },\n    ...>          run_order: 1\n    ...>        ]\n    ...>      ]\n    ...>    ],\n    ...>    [\n    ...>      name: \"Beta\",\n    ...>      actions: [\n    ...>        [\n    ...>          input_artifacts: [[name: \"MyApp\"]],\n    ...>          name: \"CodePipelineDemoFleet\",\n    ...>          action_type_id: [\n    ...>            category: \"Deploy\",\n    ...>            owner: \"AWS\",\n    ...>            version: \"1\",\n    ...>            provider: \"CodeDeploy\"\n    ...>          ],\n    ...>          output_artifacts: [],\n    ...>          configuration: %{\n    ...>            \"ApplicationName\" => \"CodePipelineDemoApplication\",\n    ...>            \"DeploymentGroupName\" => \"CodePipelineDemoFleet\"\n    ...>          },\n    ...>          run_order: 1\n    ...>        ]\n    ...>      ],\n    ...>      artifact_store: [\n    ...>        type: \"S3\",\n    ...>        location: \"codepipeline-us-east-1-11EXAMPLE11\"\n    ...>      ],\n    ...>      name: \"MySecondPipeline\",\n    ...>      version: 1\n    ...>    ]\n    ...>  ]\n    ...>] |> ExAws.CodePipeline.create_pipeline()\n    iex> keyword_pipeline_result == maps_pipeline_result\n    true","ref":"ExAws.CodePipeline.html#create_pipeline/2-examples"},{"type":"function","title":"ExAws.CodePipeline.delete_custom_action_type/3","doc":"Mark a custom action as deleted\n\n`PollForJobs` for the custom action will fail after the action\nis marked for deletion. Only used for custom actions.","ref":"ExAws.CodePipeline.html#delete_custom_action_type/3"},{"type":"function","title":"Examples - ExAws.CodePipeline.delete_custom_action_type/3","doc":"iex> ExAws.CodePipeline.delete_custom_action_type(\"Source\", \"AWS CodeDeploy\", \"1\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"category\" => \"Source\",\n        \"provider\" => \"AWS CodeDeploy\",\n        \"version\" => \"1\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.DeleteCustomActionType\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#delete_custom_action_type/3-examples"},{"type":"function","title":"ExAws.CodePipeline.delete_pipeline/1","doc":"Deletes the specified pipeline","ref":"ExAws.CodePipeline.html#delete_pipeline/1"},{"type":"function","title":"Examples - ExAws.CodePipeline.delete_pipeline/1","doc":"iex> ExAws.CodePipeline.delete_pipeline(\"MyPipeline\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"name\" => \"MyPipeline\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.DeletePipeline\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#delete_pipeline/1-examples"},{"type":"function","title":"ExAws.CodePipeline.delete_webhook/1","doc":"Delete a previously created webhook by name\n\nAfter a webhook is deleted CodePipeline does not start a pipeline every time an external event\noccurs. The API returns success if delete is for a previously deleted webhook. If a\ndeleted webhook is re-created by calling `put_webhook/1` with the same name, it will have a\ndifferent URL.","ref":"ExAws.CodePipeline.html#delete_webhook/1"},{"type":"function","title":"Examples - ExAws.CodePipeline.delete_webhook/1","doc":"iex> ExAws.CodePipeline.delete_webhook(\"MyWebhook\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"name\" => \"MyWebhook\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.DeleteWebhook\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#delete_webhook/1-examples"},{"type":"function","title":"ExAws.CodePipeline.deregister_webhook_with_third_party/1","doc":"Removes the connection between the webhook that was created by CodePipeline\nand the external tool with events to be detected\n\nCurrently only supported for webhooks that target an action type of \"GitHub\".","ref":"ExAws.CodePipeline.html#deregister_webhook_with_third_party/1"},{"type":"function","title":"Examples - ExAws.CodePipeline.deregister_webhook_with_third_party/1","doc":"iex> ExAws.CodePipeline.deregister_webhook_with_third_party(\"MyWebhook\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"webhookName\" => \"MyWebhook\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.DeregisterWebhookWithThirdParty\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#deregister_webhook_with_third_party/1-examples"},{"type":"function","title":"ExAws.CodePipeline.disable_stage_transition/4","doc":"Prevents artifacts in a pipeline from transitioning to the next stage in the pipeline","ref":"ExAws.CodePipeline.html#disable_stage_transition/4"},{"type":"function","title":"Examples - ExAws.CodePipeline.disable_stage_transition/4","doc":"iex> ExAws.CodePipeline.disable_stage_transition(\"pipeline\", \"stage\", \"Inbound\", \"Removing\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"pipelineName\" => \"pipeline\",\n        \"reason\" => \"Removing\",\n        \"stageName\" => \"stage\",\n        \"transitionType\" => \"Inbound\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.DisableStageTransition\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#disable_stage_transition/4-examples"},{"type":"function","title":"ExAws.CodePipeline.enable_stage_transition/3","doc":"Enables artifacts in a pipeline to transition to a stage in a pipeline","ref":"ExAws.CodePipeline.html#enable_stage_transition/3"},{"type":"function","title":"Examples - ExAws.CodePipeline.enable_stage_transition/3","doc":"iex> ExAws.CodePipeline.enable_stage_transition(\"pipeline\", \"stage\", \"Inbound\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"pipelineName\" => \"pipeline\",\n        \"stageName\" => \"stage\",\n        \"transitionType\" => \"Inbound\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.EnableStageTransition\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#enable_stage_transition/3-examples"},{"type":"function","title":"ExAws.CodePipeline.get_action_type/4","doc":"Returns information about an action type created for an external provider, where the action is to\nbe used by customers of the external provider\n\nThe action can be created with any supported integration model.","ref":"ExAws.CodePipeline.html#get_action_type/4"},{"type":"function","title":"Examples - ExAws.CodePipeline.get_action_type/4","doc":"iex> category = \"Test\"\n    iex> owner  = \"ThirdParty\"\n    iex> provider = \"MyJenkinsProviderName\"\n    iex> version = \"1-000-014\"\n    iex> ExAws.CodePipeline.get_action_type(category, owner, provider, version)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"category\" => \"Test\",\n        \"owner\" => \"ThirdParty\",\n        \"provider\" => \"MyJenkinsProviderName\",\n        \"version\" => \"1-000-014\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.GetActionType\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#get_action_type/4-examples"},{"type":"function","title":"ExAws.CodePipeline.get_job_details/1","doc":"Returns information about a job. Only used for custom actions","ref":"ExAws.CodePipeline.html#get_job_details/1"},{"type":"function","title":"Important - ExAws.CodePipeline.get_job_details/1","doc":"When this API is called, AWS CodePipeline returns temporary credentials for\nthe Amazon S3 bucket used to store artifacts for the pipeline, if the action\nrequires access to that Amazon S3 bucket for input or output artifacts.\nAdditionally, this API returns any secret values defined for the action.","ref":"ExAws.CodePipeline.html#get_job_details/1-important"},{"type":"function","title":"Examples - ExAws.CodePipeline.get_job_details/1","doc":"iex> job_id = \"f4f4ff82-2d11-EXAMPLE\"\n    iex> ExAws.CodePipeline.get_job_details(job_id)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"jobId\" => \"f4f4ff82-2d11-EXAMPLE\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.GetJobDetails\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#get_job_details/1-examples"},{"type":"function","title":"ExAws.CodePipeline.get_pipeline/2","doc":"Returns the metadata, structure, stages, and actions of a pipeline\n\nCan be used to return the entire structure of a pipeline in JSON format,\nwhich can then be modified and used to update the pipeline structure\nwith update_pipeline.","ref":"ExAws.CodePipeline.html#get_pipeline/2"},{"type":"function","title":"Examples - ExAws.CodePipeline.get_pipeline/2","doc":"iex> keyword_result = ExAws.CodePipeline.get_pipeline(\"MyPipeline\", [version: 1])\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"name\" => \"MyPipeline\", \"version\" => 1},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.GetPipeline\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }\n    iex> map_result = ExAws.CodePipeline.get_pipeline(\"MyPipeline\", %{version: 1})\n    iex> keyword_result == map_result\n    true","ref":"ExAws.CodePipeline.html#get_pipeline/2-examples"},{"type":"function","title":"ExAws.CodePipeline.get_pipeline_execution/2","doc":"Returns information about an execution of a pipeline, including details\nabout artifacts, the pipeline execution ID, and the name, version, and\nstatus of the pipeline","ref":"ExAws.CodePipeline.html#get_pipeline_execution/2"},{"type":"function","title":"Examples - ExAws.CodePipeline.get_pipeline_execution/2","doc":"iex> pipeline_name = \"MyPipeline\"\n    iex> pipeline_execution_id = \"0244417fff\"\n    iex> ExAws.CodePipeline.get_pipeline_execution(pipeline_name, pipeline_execution_id)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"pipelineExecutionId\" => \"0244417fff\",\n        \"pipelineName\" => \"MyPipeline\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.GetPipelineExecution\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#get_pipeline_execution/2-examples"},{"type":"function","title":"ExAws.CodePipeline.get_pipeline_state/1","doc":"Returns information about the state of a pipeline, including the stages and actions","ref":"ExAws.CodePipeline.html#get_pipeline_state/1"},{"type":"function","title":"Examples - ExAws.CodePipeline.get_pipeline_state/1","doc":"iex> pipeline_name = \"MyPipeline\"\n    iex> ExAws.CodePipeline.get_pipeline_state(pipeline_name)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"name\" => \"MyPipeline\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.GetPipelineState\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#get_pipeline_state/1-examples"},{"type":"function","title":"ExAws.CodePipeline.get_third_party_job_details/2","doc":"Requests the details of a job for a third party action. Only used for partner actions\n\nIMPORTANT: When this API is called, AWS CodePipeline returns temporary credentials\nfor the Amazon S3 bucket used to store artifacts for the pipeline, if the action\nrequires access to that Amazon S3 bucket for input or output artifacts. Additionally,\nthis API returns any secret values defined for the action.","ref":"ExAws.CodePipeline.html#get_third_party_job_details/2"},{"type":"function","title":"Examples - ExAws.CodePipeline.get_third_party_job_details/2","doc":"iex> job_id = \"f4f4ff82-2d11-EXAMPLE\"\n    iex> client_token = \"ClientToken\"\n    iex> ExAws.CodePipeline.get_third_party_job_details(job_id, client_token)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"clientToken\" => \"ClientToken\", \"jobId\" => \"f4f4ff82-2d11-EXAMPLE\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.GetThirdPartyJobDetails\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#get_third_party_job_details/2-examples"},{"type":"function","title":"ExAws.CodePipeline.list_action_executions/2","doc":"Lists the action executions that have occurred in a pipeline\n\nThis is a paginated operation. Multiple API calls may be issued in order to retrieve the entire\ndata set of results.","ref":"ExAws.CodePipeline.html#list_action_executions/2"},{"type":"function","title":"Examples - ExAws.CodePipeline.list_action_executions/2","doc":"iex> pipeline_name = \"MyPipeline\"\n    iex> ExAws.CodePipeline.list_action_executions(pipeline_name)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"pipelineName\" => \"MyPipeline\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.ListActionExecutions\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }\n\n    iex> pipeline_name = \"MyPipeline\"\n    iex> list_action_executions_optional = %{next_token: \"4AEA6u7J23429JFF212\"}\n    iex> ExAws.CodePipeline.list_action_executions(pipeline_name, list_action_executions_optional)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"nextToken\" => \"4AEA6u7J23429JFF212\", \"pipelineName\" => \"MyPipeline\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.ListActionExecutions\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#list_action_executions/2-examples"},{"type":"function","title":"ExAws.CodePipeline.list_action_types/1","doc":"Gets a summary of all AWS CodePipeline action types associated with your account","ref":"ExAws.CodePipeline.html#list_action_types/1"},{"type":"function","title":"Examples - ExAws.CodePipeline.list_action_types/1","doc":"iex> list_action_types_optional = [action_owner_filter: \"MyFilter\", next_token: \"ClientToken\"]\n    iex> ExAws.CodePipeline.list_action_types(list_action_types_optional)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"actionOwnerFilter\" => \"MyFilter\", \"nextToken\" => \"ClientToken\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.ListActionTypes\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#list_action_types/1-examples"},{"type":"function","title":"ExAws.CodePipeline.list_pipeline_executions/2","doc":"Gets a summary of the most recent executions for a pipeline","ref":"ExAws.CodePipeline.html#list_pipeline_executions/2"},{"type":"function","title":"Notes - ExAws.CodePipeline.list_pipeline_executions/2","doc":"When applying the filter for pipeline executions that have succeeded in the stage, the operation\nreturns all executions in the current pipeline version beginning on February 1, 2024.","ref":"ExAws.CodePipeline.html#list_pipeline_executions/2-notes"},{"type":"function","title":"Examples - ExAws.CodePipeline.list_pipeline_executions/2","doc":"iex> ExAws.CodePipeline.list_pipeline_executions(\"MyPipeline\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"pipelineName\" => \"MyPipeline\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.ListPipelineExecutions\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#list_pipeline_executions/2-examples"},{"type":"function","title":"ExAws.CodePipeline.list_pipelines/1","doc":"Gets a summary of all of the pipelines associated with your account","ref":"ExAws.CodePipeline.html#list_pipelines/1"},{"type":"function","title":"Examples - ExAws.CodePipeline.list_pipelines/1","doc":"iex> ExAws.CodePipeline.list_pipelines()\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.ListPipelines\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#list_pipelines/1-examples"},{"type":"function","title":"ExAws.CodePipeline.list_rule_executions/2","doc":"Lists the rule executions that have occurred in a pipeline configured for conditions with rules","ref":"ExAws.CodePipeline.html#list_rule_executions/2"},{"type":"function","title":"Examples - ExAws.CodePipeline.list_rule_executions/2","doc":"iex> pipeline_name = \"MyPipeline\"\n    iex> ExAws.CodePipeline.list_rule_executions(pipeline_name)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"pipelineName\" => \"MyPipeline\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.ListRuleExecutions\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#list_rule_executions/2-examples"},{"type":"function","title":"ExAws.CodePipeline.list_rule_types/1","doc":"Lists the rules for the condition","ref":"ExAws.CodePipeline.html#list_rule_types/1"},{"type":"function","title":"Examples - ExAws.CodePipeline.list_rule_types/1","doc":"iex> ExAws.CodePipeline.list_rule_types()\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.ListRuleTypes\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#list_rule_types/1-examples"},{"type":"function","title":"ExAws.CodePipeline.list_tags_for_resource/2","doc":"Gets the set of key-value pairs (metadata) that are used to manage the resource","ref":"ExAws.CodePipeline.html#list_tags_for_resource/2"},{"type":"function","title":"Examples - ExAws.CodePipeline.list_tags_for_resource/2","doc":"iex> resource_arn = \"arn:aws:iam::111111111111:codepipeline:012345678901\"\n    iex> ExAws.CodePipeline.list_tags_for_resource(resource_arn)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"resourceArn\" => \"arn:aws:iam::111111111111:codepipeline:012345678901\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.ListTagsForResource\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#list_tags_for_resource/2-examples"},{"type":"function","title":"ExAws.CodePipeline.list_webhooks/1","doc":"Gets a listing of all the webhooks in this region for this account\n\nThe output lists all webhooks and includes the webhook URL and ARN,\nas well the configuration for each webhook.\n\nNote: If a secret token was provided, it will be redacted in the response.","ref":"ExAws.CodePipeline.html#list_webhooks/1"},{"type":"function","title":"Examples - ExAws.CodePipeline.list_webhooks/1","doc":"iex> ExAws.CodePipeline.list_webhooks()\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.ListWebhooks\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#list_webhooks/1-examples"},{"type":"function","title":"ExAws.CodePipeline.override_stage_condition/4","doc":"Used to override a stage condition","ref":"ExAws.CodePipeline.html#override_stage_condition/4"},{"type":"function","title":"Examples - ExAws.CodePipeline.override_stage_condition/4","doc":"iex> pipeline_name = \"MyPipeline\"\n    iex> stage_name = \"Deploy2Stage\"\n    iex> pipeline_execution_id = \"0244417fff\"\n    iex> condition_type = \"BEFORE_ENTRY\"\n    iex> ExAws.CodePipeline.override_stage_condition(pipeline_name, stage_name, pipeline_execution_id, condition_type)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"conditionType\" => \"BEFORE_ENTRY\",\n        \"pipelineExecutionId\" => \"0244417fff\",\n        \"pipelineName\" => \"MyPipeline\",\n        \"stageName\" => \"Deploy2Stage\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.OverrideStageCondition\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#override_stage_condition/4-examples"},{"type":"function","title":"ExAws.CodePipeline.poll_for_jobs/2","doc":"Returns information about any jobs for AWS CodePipeline to act upon","ref":"ExAws.CodePipeline.html#poll_for_jobs/2"},{"type":"function","title":"Notes - ExAws.CodePipeline.poll_for_jobs/2","doc":"The API `poll_for_jobs/2` is only valid for action types with \"Custom\" in the owner field.\nIf the action type contains \"AWS\" or \"ThirdParty\" in the owner field, the\n`poll_for_jobs/2` call to the AWS API returns an error.\n\n**Important**: When this API is called, CodePipeline returns temporary credentials for the S3\nbucket used to store artifacts for the pipeline, if the action requires access to that S3 bucket\nfor input or output artifacts. This API also returns any secret values defined for the action.","ref":"ExAws.CodePipeline.html#poll_for_jobs/2-notes"},{"type":"function","title":"Examples - ExAws.CodePipeline.poll_for_jobs/2","doc":"iex> action_type_id = [category: \"Build\", owner: \"AWS\", provider: \"AWS CodeDeploy\", version: \"1\"]\n    iex> ExAws.CodePipeline.poll_for_jobs(action_type_id)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"actionTypeId\" => %{\n          \"category\" => \"Build\",\n          \"owner\" => \"AWS\",\n          \"provider\" => \"AWS CodeDeploy\",\n          \"version\" => \"1\"\n        }\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.PollForJobs\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#poll_for_jobs/2-examples"},{"type":"function","title":"ExAws.CodePipeline.poll_for_third_party_jobs/2","doc":"Determines whether there are any third party jobs for a job worker to act on","ref":"ExAws.CodePipeline.html#poll_for_third_party_jobs/2"},{"type":"function","title":"Notes - ExAws.CodePipeline.poll_for_third_party_jobs/2","doc":"Only used for partner actions.\n\n**Important** When this API is called, AWS CodePipeline returns temporary credentials for the\nAmazon S3 bucket used to store artifacts for the pipeline, if the action requires access to that\nAmazon S3 bucket for input or output artifacts.","ref":"ExAws.CodePipeline.html#poll_for_third_party_jobs/2-notes"},{"type":"function","title":"Examples - ExAws.CodePipeline.poll_for_third_party_jobs/2","doc":"iex> action_type_id = [category: \"Build\", owner: \"Custom\", provider: \"MyProvider\", version: \"1\"]\n    iex> ExAws.CodePipeline.poll_for_third_party_jobs(action_type_id)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"actionTypeId\" => %{\n          \"category\" => \"Build\",\n          \"owner\" => \"Custom\",\n          \"provider\" => \"MyProvider\",\n          \"version\" => \"1\"\n        }\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.PollForThirdPartyJobs\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#poll_for_third_party_jobs/2-examples"},{"type":"function","title":"ExAws.CodePipeline.put_action_revision/4","doc":"Provides information to AWS CodePipeline about new revisions to a source","ref":"ExAws.CodePipeline.html#put_action_revision/4"},{"type":"function","title":"Examples - ExAws.CodePipeline.put_action_revision/4","doc":"iex> alias ExAws.CodePipeline\n    iex> action_revision = %{\n    ...>   created: \"2024-09-01T12:00:00Z\",\n    ...>   revision_change_id: \"3fdd7b9196697a096d5af1d649e26a4a\",\n    ...>   revision_id: \"HYGp7zmwbCPPwo234xsCEM7d6ToeAqIl\"\n    ...> }\n    iex> pipeline_name = \"MyPipeline\"\n    iex> stage_name = \"Deploy2Stage\"\n    iex> action_name = \"Source\"\n    iex> CodePipeline.put_action_revision(pipeline_name, stage_name, action_name, action_revision)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"actionName\" => \"Source\",\n        \"actionRevision\" => %{\n          \"created\" => \"2024-09-01T12:00:00Z\",\n          \"revisionChangeId\" => \"3fdd7b9196697a096d5af1d649e26a4a\",\n          \"revisionId\" => \"HYGp7zmwbCPPwo234xsCEM7d6ToeAqIl\"\n        },\n        \"pipelineName\" => \"MyPipeline\",\n        \"stageName\" => \"Deploy2Stage\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.PutActionRevision\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#put_action_revision/4-examples"},{"type":"function","title":"ExAws.CodePipeline.put_approval_result/5","doc":"Provides the response to a manual approval request to AWS CodePipeline\n\nValid responses include \"Approved\" and \"Rejected\".","ref":"ExAws.CodePipeline.html#put_approval_result/5"},{"type":"function","title":"Examples - ExAws.CodePipeline.put_approval_result/5","doc":"iex> pipeline_name = \"MyPipeline\"\n    iex> stage_name = \"Deploy2Stage\"\n    iex> action_name = \"Source\"\n    iex> approval_token = \"92382348AFF\"\n    iex> approval_result = %{status: \"Approved\", summary: \"Ready to Deploy\"}\n    iex> alias ExAws.CodePipeline\n    iex> CodePipeline.put_approval_result(pipeline_name, stage_name, action_name,\n    ...>   approval_token, approval_result)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"actionName\" => \"Source\",\n        \"pipelineName\" => \"MyPipeline\",\n        \"result\" => %{\"status\" => \"Approved\", \"summary\" => \"Ready to Deploy\"},\n        \"stageName\" => \"Deploy2Stage\",\n        \"token\" => \"92382348AFF\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.PutApprovalResult\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#put_approval_result/5-examples"},{"type":"function","title":"ExAws.CodePipeline.put_job_failure_result/2","doc":"Represents the failure of a job as returned to the pipeline by a job worker\n\nOnly used for custom actions.","ref":"ExAws.CodePipeline.html#put_job_failure_result/2"},{"type":"function","title":"Examples - ExAws.CodePipeline.put_job_failure_result/2","doc":"iex> job_id = \"f4f4ff82-2d11-EXAMPLE\"\n    iex> ExAws.CodePipeline.put_job_failure_result(job_id, [external_execution_id: \"id\", message: \"\", type: \"JobFailed\"] )\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"externalExecutionId\" => \"id\",\n        \"jobId\" => \"f4f4ff82-2d11-EXAMPLE\",\n        \"message\" => \"\",\n        \"type\" => \"JobFailed\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.PutJobFailureResult\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#put_job_failure_result/2-examples"},{"type":"function","title":"ExAws.CodePipeline.put_job_success_result/2","doc":"Represents the success of a job as returned to the pipeline by a job worker\n\nOnly used for custom actions.","ref":"ExAws.CodePipeline.html#put_job_success_result/2"},{"type":"function","title":"Examples - ExAws.CodePipeline.put_job_success_result/2","doc":"iex> job_id = \"f4f4ff82-2d11-EXAMPLE\"\n    iex> revision = %{change_identifier: \"Change20240711\", revision: \"23443ffEXAMPLE\"}\n    iex> job_success_result = %{current_revision: revision, execution_details: %{percent_complete: 50}}\n    iex> ExAws.CodePipeline.put_job_success_result(job_id, job_success_result)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"currentRevision\" => %{\n          \"changeIdentifier\" => \"Change20240711\",\n          \"revision\" => \"23443ffEXAMPLE\"\n        },\n        \"executionDetails\" => %{\"percentComplete\" => 50},\n        \"jobId\" => \"f4f4ff82-2d11-EXAMPLE\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.PutJobSuccessResult\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#put_job_success_result/2-examples"},{"type":"function","title":"ExAws.CodePipeline.put_third_party_job_failure_result/3","doc":"Represents the failure of a third party job as returned to the pipeline by a job worker","ref":"ExAws.CodePipeline.html#put_third_party_job_failure_result/3"},{"type":"function","title":"Notes - ExAws.CodePipeline.put_third_party_job_failure_result/3","doc":"Only used for partner actions.\n\nAll 3 parameters are required. In `t:failure_details/0` the message and type must be set.","ref":"ExAws.CodePipeline.html#put_third_party_job_failure_result/3-notes"},{"type":"function","title":"Examples - ExAws.CodePipeline.put_third_party_job_failure_result/3","doc":"iex> job_id = \"f4f4ff82-2d11-EXAMPLE\"\n    iex> client_token = \"ClientToken\"\n    iex> failure_details = %{message: \"Problem occurred\", type: \"JobFailed\"}\n    iex> ExAws.CodePipeline.put_third_party_job_failure_result(job_id, client_token, failure_details)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"clientToken\" => \"ClientToken\",\n        \"failureDetails\" => %{\n          \"message\" => \"Problem occurred\",\n          \"type\" => \"JobFailed\"\n        },\n        \"jobId\" => \"f4f4ff82-2d11-EXAMPLE\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.PutThirdPartyJobFailureResult\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#put_third_party_job_failure_result/3-examples"},{"type":"function","title":"ExAws.CodePipeline.put_third_party_job_success_result/3","doc":"Represents the success of a third party job as returned to the pipeline by a job worker.","ref":"ExAws.CodePipeline.html#put_third_party_job_success_result/3"},{"type":"function","title":"Notes - ExAws.CodePipeline.put_third_party_job_success_result/3","doc":"Only used for partner actions.","ref":"ExAws.CodePipeline.html#put_third_party_job_success_result/3-notes"},{"type":"function","title":"Examples - ExAws.CodePipeline.put_third_party_job_success_result/3","doc":"iex> job_id = \"f4f4ff82-2d11-EXAMPLE\"\n    iex> client_token = \"ClientToken\"\n    iex> ExAws.CodePipeline.put_third_party_job_success_result(job_id, client_token)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"clientToken\" => \"ClientToken\", \"jobId\" => \"f4f4ff82-2d11-EXAMPLE\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.PutThirdPartyJobSuccessResult\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#put_third_party_job_success_result/3-examples"},{"type":"function","title":"ExAws.CodePipeline.put_webhook/2","doc":"Defines a webhook and returns a unique webhook URL generated by CodePipeline","ref":"ExAws.CodePipeline.html#put_webhook/2"},{"type":"function","title":"Notes - ExAws.CodePipeline.put_webhook/2","doc":"This URL can be supplied to third party source hosting providers to call every time there's a code\nchange. When CodePipeline receives a POST request on this URL, the pipeline defined in the webhook\nis started as long as the POST request satisfied the authentication and filtering requirements\nsupplied when defining the webhook. `register_webhook_with_third_party/1` and\n`deregister_webhook_with_third_party/1` APIs can be used to automatically configure supported\nthird parties to call the generated webhook URL.","ref":"ExAws.CodePipeline.html#put_webhook/2-notes"},{"type":"function","title":"Examples - ExAws.CodePipeline.put_webhook/2","doc":"iex> webhook_definition = %{\n    ...>  authentication: \"IP\",\n    ...>  authentication_configuration: %{\n    ...>    allowed_IP_range: \"192.168.0.15/24\"\n    ...>  },\n    ...>  filters: [%{json_path: \"$.ref\", match_equals: \"refs/heads/{Branch}\"}],\n    ...>  name: \"MyWebHook\",\n    ...>  target_action: \"source_action_name\",\n    ...>  target_pipeline: \"pipeline_name\"\n    ...>}\n    iex> ExAws.CodePipeline.put_webhook(webhook_definition)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"tags\" => [],\n        \"webhook\" => %{\n          \"authentication\" => \"IP\",\n          \"authenticationConfiguration\" => %{\"allowedIPRange\" => \"192.168.0.15/24\"},\n          \"filters\" => [\n            %{\"jsonPath\" => \"$.ref\", \"matchEquals\" => \"refs/heads/{Branch}\"}\n          ],\n          \"name\" => \"MyWebHook\",\n          \"targetAction\" => \"source_action_name\",\n          \"targetPipeline\" => \"pipeline_name\"\n        }\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.PutWebhook\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#put_webhook/2-examples"},{"type":"function","title":"ExAws.CodePipeline.register_webhook_with_third_party/1","doc":"Configures a connection between the webhook that was created and the external tool with events to\nbe detected","ref":"ExAws.CodePipeline.html#register_webhook_with_third_party/1"},{"type":"function","title":"Examples - ExAws.CodePipeline.register_webhook_with_third_party/1","doc":"iex> ExAws.CodePipeline.register_webhook_with_third_party(\"MyWebHook\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"webhookName\" => \"MyWebHook\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.RegisterWebhookWithThirdParty\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#register_webhook_with_third_party/1-examples"},{"type":"function","title":"ExAws.CodePipeline.retry_stage_execution/4","doc":"Resumes the pipeline execution by retrying the last failed actions in a stage","ref":"ExAws.CodePipeline.html#retry_stage_execution/4"},{"type":"function","title":"Examples - ExAws.CodePipeline.retry_stage_execution/4","doc":"iex> ExAws.CodePipeline.retry_stage_execution(\"MyPipeline\", \"MyStage\", \"ExecutionId\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"pipelineExecutionId\" => \"ExecutionId\",\n        \"pipelineName\" => \"MyPipeline\",\n        \"retryMode\" => \"FAILED_ACTIONS\",\n        \"stageName\" => \"MyStage\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.RetryStageExecution\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#retry_stage_execution/4-examples"},{"type":"function","title":"ExAws.CodePipeline.rollback_stage/3","doc":"Rolls back a stage execution","ref":"ExAws.CodePipeline.html#rollback_stage/3"},{"type":"function","title":"Examples - ExAws.CodePipeline.rollback_stage/3","doc":"iex> pipeline_name = \"MyPipeline\"\n    iex> stage_name = \"Deploy2Stage\"\n    iex> pipeline_execution_id = \"0244417fff\"\n    iex> ExAws.CodePipeline.rollback_stage(pipeline_name, stage_name, pipeline_execution_id)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"pipelineName\" => \"MyPipeline\",\n        \"stageName\" => \"Deploy2Stage\",\n        \"targetPipelineExecutionId\" => \"0244417fff\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.RollbackStage\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#rollback_stage/3-examples"},{"type":"function","title":"ExAws.CodePipeline.start_pipeline_execution/2","doc":"Starts the specified pipeline\n\nSpecifically, it begins processing the latest commit to the\nsource location specified as part of the pipeline.","ref":"ExAws.CodePipeline.html#start_pipeline_execution/2"},{"type":"function","title":"Examples - ExAws.CodePipeline.start_pipeline_execution/2","doc":"iex> ExAws.CodePipeline.start_pipeline_execution(\"MyPipeline\", [client_request_token: \"Test\"])\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"clientRequestToken\" => \"Test\", \"name\" => \"MyPipeline\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.StartPipelineExecution\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#start_pipeline_execution/2-examples"},{"type":"function","title":"ExAws.CodePipeline.stop_pipeline_execution/3","doc":"Stops the specified pipeline execution","ref":"ExAws.CodePipeline.html#stop_pipeline_execution/3"},{"type":"function","title":"Notes - ExAws.CodePipeline.stop_pipeline_execution/3","doc":"You choose to either stop the pipeline execution by completing in-progress actions without\nstarting subsequent actions, or by abandoning in-progress actions. While completing or abandoning\nin-progress actions, the pipeline execution is in a Stopping state. After all in-progress actions\nare completed or abandoned, the pipeline execution is in a Stopped state.","ref":"ExAws.CodePipeline.html#stop_pipeline_execution/3-notes"},{"type":"function","title":"Examples - ExAws.CodePipeline.stop_pipeline_execution/3","doc":"iex> pipeline_name = \"MyPipeline\"\n    iex> pipeline_execution_id = \"0244417fff\"\n    iex> ExAws.CodePipeline.stop_pipeline_execution(pipeline_name, pipeline_execution_id)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{pipeline_name: \"MyPipeline\", pipeline_execution_id: \"0244417fff\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.StopPipelineExecution\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#stop_pipeline_execution/3-examples"},{"type":"function","title":"ExAws.CodePipeline.tag_resource/2","doc":"Adds to or modifies the tags of the given resource","ref":"ExAws.CodePipeline.html#tag_resource/2"},{"type":"function","title":"Notes - ExAws.CodePipeline.tag_resource/2","doc":"Tags are metadata that can be used to manage a resource.","ref":"ExAws.CodePipeline.html#tag_resource/2-notes"},{"type":"function","title":"Examples - ExAws.CodePipeline.tag_resource/2","doc":"iex> resource_arn = \"arn:aws:iam::111111111111:codepipeline:012345678901\"\n    iex> tags = [%{key: \"Team\", value: \"SRE\"}, %{key: \"project\", value: \"Test\"}]\n    iex> ExAws.CodePipeline.tag_resource(resource_arn, tags)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"resourceArn\" => \"arn:aws:iam::111111111111:codepipeline:012345678901\",\n        \"tags\" => [\n          %{\"key\" => \"Team\", \"value\" => \"SRE\"},\n          %{\"key\" => \"project\", \"value\" => \"Test\"}\n        ]\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.TagResource\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#tag_resource/2-examples"},{"type":"function","title":"ExAws.CodePipeline.untag_resource/2","doc":"Removes tags from an AWS resource","ref":"ExAws.CodePipeline.html#untag_resource/2"},{"type":"function","title":"Examples - ExAws.CodePipeline.untag_resource/2","doc":"iex> resource_arn = \"arn:aws:iam::111111111111:codepipeline:012345678901\"\n    iex> tag_keys = [\"Team\"]\n    iex> ExAws.CodePipeline.untag_resource(resource_arn, tag_keys)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"resourceArn\" => \"arn:aws:iam::111111111111:codepipeline:012345678901\",\n        \"tagKeys\" => [\"Team\"]\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.UntagResource\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#untag_resource/2-examples"},{"type":"function","title":"ExAws.CodePipeline.update_action_type/6","doc":"Updates an action type that was created with any supported integration model, where the action\ntype is to be used by customers of the action type provider","ref":"ExAws.CodePipeline.html#update_action_type/6"},{"type":"function","title":"Examples - ExAws.CodePipeline.update_action_type/6","doc":"iex> alias ExAws.CodePipeline\n    iex> version = 1\n    iex> category = \"Build\"\n    iex> provider = \"MyJenkinsProviderName\"\n    iex> input_artifact_details = %{maximum_count: 1, minimum_count: 0}\n    iex> output_artifact_details = %{maximum_count: 1, minimum_count: 0}\n    iex> opts = %{\n    ...>  settings: %{\n    ...>    entity_url_template: \"https://192.0.2.4/job/{Config:ProjectName}/\",\n    ...>    execution_url_template: \"https://192.0.2.4/job/{Config:ProjectName}/lastSuccessfulBuild/{ExternalExecutionId}/\"\n    ...> },\n    ...> configuration_properties: [\n    ...>   %{\n    ...>      name: \"MyJenkinsExampleBuildProject\",\n    ...>      type: \"String\",\n    ...>      description: \"The name of the build project must be provided when this action is added to the pipeline.\",\n    ...>      key: true,\n    ...>      required: true,\n    ...>      secret: false,\n    ...>      queryable: false\n    ...>    }\n    ...>  ],\n    ...>  tags: [%{key: \"test\", value: \"TaggingValue\"}]\n    ...> }\n    iex> map_result = CodePipeline.update_action_type(category, provider, version,\n    ...>                                              input_artifact_details,\n    ...>                                              output_artifact_details,\n    ...>                                              opts)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"category\" => \"Build\",\n        \"configurationProperties\" => [\n          %{\n            \"description\" => \"The name of the build project must be provided when this action is added to the pipeline.\",\n            \"key\" => true,\n            \"name\" => \"MyJenkinsExampleBuildProject\",\n            \"queryable\" => false,\n            \"required\" => true,\n            \"secret\" => false,\n            \"type\" => \"String\"\n          }\n        ],\n        \"inputArtifactDetails\" => %{\"maximumCount\" => 1, \"minimumCount\" => 0},\n        \"outputArtifactDetails\" => %{\"maximumCount\" => 1, \"minimumCount\" => 0},\n        \"provider\" => \"MyJenkinsProviderName\",\n        \"settings\" => %{\n          \"entityUrlTemplate\" => \"https://192.0.2.4/job/{Config:ProjectName}/\",\n          \"executionUrlTemplate\" => \"https://192.0.2.4/job/{Config:ProjectName}/lastSuccessfulBuild/{ExternalExecutionId}/\"\n        },\n        \"tags\" => [\n          %{\"key\" => \"test\", \"value\" => \"TaggingValue\"}\n        ],\n        \"version\" => 1\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.UpdateActionType\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }\n    iex> keyword_opts = [\n    ...>  settings: [\n    ...>    entity_url_template: \"https://192.0.2.4/job/{Config:ProjectName}/\",\n    ...>    execution_url_template: \"https://192.0.2.4/job/{Config:ProjectName}/lastSuccessfulBuild/{ExternalExecutionId}/\"\n    ...>  ],\n    ...>  configuration_properties: [\n    ...>    [\n    ...>      name: \"MyJenkinsExampleBuildProject\",\n    ...>      type: \"String\",\n    ...>      description: \"The name of the build project must be provided when this action is added to the pipeline.\",\n    ...>      key: true,\n    ...>      required: true,\n    ...>      secret: false,\n    ...>      queryable: false\n    ...>    ]\n    ...>  ],\n    ...>  tags: [[key: \"test\", value: \"TaggingValue\"]]\n    ...>]\n    iex> keyword_result = CodePipeline.update_action_type(category, provider, version,\n    ...>                                                  input_artifact_details,\n    ...>                                                  output_artifact_details,\n    ...>                                                  keyword_opts)\n    iex> map_result == keyword_result\n    true\n    iex> ###########################################################################\n    iex> # The above demonstrates that using Keyword or Map for input\n    iex> # does not matter. They produce the same `ExAws.Operation.JSON.t`\n    iex> ###########################################################################","ref":"ExAws.CodePipeline.html#update_action_type/6-examples"},{"type":"function","title":"ExAws.CodePipeline.update_pipeline/1","doc":"Updates a specified pipeline with edits or changes to its structure.\n\nUse a JSON file with the pipeline structure in conjunction with update_pipeline\nto provide the full structure of the pipeline. Updating the pipeline increases\nthe version number of the pipeline by 1.\n\n    iex> %{\n    ...>  role_arn: \"arn:aws:iam::111111111111:role/AWS-CodePipeline-Service\",\n    ...>  stages: [\n    ...>    %{\n    ...>      name: \"Source\",\n    ...>      actions: [\n    ...>        %{\n    ...>          name: \"Source\",\n    ...>          action_type_id: %{\n    ...>            owner: \"AWS\",\n    ...>            version: \"1\",\n    ...>            category: \"Source\",\n    ...>            provider: \"S3\"\n    ...>          },\n    ...>          configuration: %{\n    ...>            \"S3Bucket\" => \"awscodepipeline-demo-bucket\",\n    ...>            \"S3ObjectKey\" => \"aws-codepipeline-s3-aws-codedeploy_linux.zip\"\n    ...>          },\n    ...>          input_artifacts: [],\n    ...>          run_order: 1,\n    ...>          output_artifacts: [%{name: \"MyApp\"}]\n    ...>        }\n    ...>      ]\n    ...>    },\n    ...>    %{\n    ...>      name: \"MySecondPipeline\",\n    ...>      version: 1,\n    ...>      artifact_store: %{\n    ...>        type: \"S3\",\n    ...>        location: \"codepipeline-us-east-1-11EXAMPLE11\"\n    ...>      },\n    ...>      actions: [\n    ...>        %{\n    ...>          name: \"CodePipelineDemoFleet\",\n    ...>          action_type_id: %{\n    ...>            owner: \"AWS\",\n    ...>            version: \"1\",\n    ...>            category: \"Deploy\",\n    ...>            provider: \"CodeDeploy\"\n    ...>          },\n    ...>          configuration: %{\n    ...>            \"ApplicationName\" => \"CodePipelineDemoApplication\",\n    ...>            \"DeploymentGroupName\" => \"CodePipelineDemoFleet\"\n    ...>          },\n    ...>          input_artifacts: [%{name: \"MyApp\"}],\n    ...>          run_order: 1,\n    ...>          output_artifacts: []\n    ...>        }\n    ...>      ]\n    ...>    }\n    ...>  ]\n    ...>} |> ExAws.CodePipeline.update_pipeline()\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"pipeline\" => %{\n          \"roleArn\" => \"arn:aws:iam::111111111111:role/AWS-CodePipeline-Service\",\n          \"stages\" => [\n            %{\n              \"actions\" => [\n                %{\n                  \"actionTypeId\" => %{\n                    \"category\" => \"Source\",\n                    \"owner\" => \"AWS\",\n                    \"provider\" => \"S3\",\n                    \"version\" => \"1\"\n                  },\n                  \"configuration\" => %{\n                    \"S3Bucket\" => \"awscodepipeline-demo-bucket\",\n                    \"S3ObjectKey\" => \"aws-codepipeline-s3-aws-codedeploy_linux.zip\"\n                  },\n                  \"inputArtifacts\" => [],\n                  \"name\" => \"Source\",\n                  \"outputArtifacts\" => [%{\"name\" => \"MyApp\"}],\n                  \"runOrder\" => 1\n                }\n              ],\n              \"name\" => \"Source\"\n            },\n            %{\n              \"actions\" => [\n                %{\n                  \"actionTypeId\" => %{\n                    \"category\" => \"Deploy\",\n                    \"owner\" => \"AWS\",\n                    \"provider\" => \"CodeDeploy\",\n                    \"version\" => \"1\"\n                  },\n                  \"configuration\" => %{\n                    \"ApplicationName\" => \"CodePipelineDemoApplication\",\n                    \"DeploymentGroupName\" => \"CodePipelineDemoFleet\"\n                  },\n                  \"inputArtifacts\" => [%{\"name\" => \"MyApp\"}],\n                  \"name\" => \"CodePipelineDemoFleet\",\n                  \"outputArtifacts\" => [],\n                  \"runOrder\" => 1\n                }\n              ],\n              \"artifactStore\" => %{\n                \"location\" => \"codepipeline-us-east-1-11EXAMPLE11\",\n                \"type\" => \"S3\"\n              },\n              \"name\" => \"MySecondPipeline\",\n              \"version\" => 1\n            }\n          ]\n        }\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodePipeline_20150709.UpdatePipeline\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codepipeline,\n      before_request: nil\n    }","ref":"ExAws.CodePipeline.html#update_pipeline/1"},{"type":"type","title":"ExAws.CodePipeline.action_category/0","doc":"A category defines what kind of action can be taken in the stage, and constrains the provider type\nfor the action.\n\nValid Values\n```\n[\"Source\", \"Build\", \"Deploy\", \"Test\", \"Invoke\", \"Approval\"]\n```","ref":"ExAws.CodePipeline.html#t:action_category/0"},{"type":"type","title":"ExAws.CodePipeline.action_configuration_key/0","doc":"The name of the action configuration property\n\n- Length Constraints: Minimum length of 1. Maximum length of 50.","ref":"ExAws.CodePipeline.html#t:action_configuration_key/0"},{"type":"type","title":"ExAws.CodePipeline.action_configuration_map/0","doc":"The action's configuration.\n\nThese are key-value pairs that specify input values for an action. For more information, see\nAction Structure Requirements in CodePipeline. For the list of configuration properties for the\nAWS CloudFormation action type in CodePipeline, see Configuration Properties Reference in the AWS\nCloudFormation User Guide. For template snippets with examples, see Using Parameter Override\nFunctions with CodePipeline Pipelines in the AWS CloudFormation User Guide.\n\n- Key Length Constraints: Minimum length of 1. Maximum length of 50.\n- Value Length Constraints: Minimum length of 1. Maximum length of 1000.","ref":"ExAws.CodePipeline.html#t:action_configuration_map/0"},{"type":"type","title":"ExAws.CodePipeline.action_configuration_property/0","doc":"Represents information about an action configuration property\n\n- description - The description of the action configuration property that is displayed to users.\n- key - Whether the configuration property is a key\n- name - The name of the action configuration property.\n- queryable - Indicates that the property is used with `poll_for_jobs/2`.\n  - When creating a custom action, an action can have up to one queryable property. If it has one,\n  that property must be both required and not secret.\n  - If you create a pipeline with a custom action type, and that custom action contains a\n    queryable property, the value for that configuration property is subject to other\n    restrictions. The value must be less than or equal to twenty (20) characters. The value can\n    contain only alphanumeric characters, underscores, and hyphens.\n- required - Whether the configuration property is a required value.\n- secret - Whether the configuration property is secret. Secrets are hidden from all calls except\n  for `get_job_details/1`, `get_third_party_job_details/2`, `poll_for_jobs/2`, and `poll_for_third_party_jobs/2`.\n- type - The type of the configuration property.","ref":"ExAws.CodePipeline.html#t:action_configuration_property/0"},{"type":"type","title":"Valid Values - ExAws.CodePipeline.action_configuration_property/0","doc":"```\n  [\"String\", \"Number\", \"Boolean\"]\n  ```","ref":"ExAws.CodePipeline.html#t:action_configuration_property/0-valid-values"},{"type":"type","title":"ExAws.CodePipeline.action_configuration_property_type/0","doc":"The type of the configuration property\n\nValid Values\n```\n[\"String\", \"Number\", \"Boolean\"]\n```","ref":"ExAws.CodePipeline.html#t:action_configuration_property_type/0"},{"type":"type","title":"ExAws.CodePipeline.action_declaration/0","doc":"Represents information about an action declaration\n\n- action_type_id - Specifies the action type and the provider of the action.\n- name - The action declaration's name\n- configuration - The action's configuration\n- input_artifacts - The name or ID of the artifact consumed by the action, such as a test or build\n  artifact\n- namespace - The variable namespace associated with the action\n- output_artifacts - The name or ID of the result of the action declaration, such as a test or\n  build artifact\n- region - The action declaration's AWS Region, such as us-east-1\n- role_arn - The ARN of the IAM service role that performs the declared action\n- run_order - The order in which actions are run\n- timeout_in_minutes - A timeout duration in minutes that can be applied against the ActionType’s\ndefault timeout value specified in Quotas for AWS CodePipeline","ref":"ExAws.CodePipeline.html#t:action_declaration/0"},{"type":"type","title":"ExAws.CodePipeline.action_execution_filter/0","doc":"Filter values for the action execution\n\n- latest_in_pipeline_execution - The latest execution in the pipeline\n- pipeline_execution_id - The pipeline execution ID used to filter action execution history","ref":"ExAws.CodePipeline.html#t:action_execution_filter/0"},{"type":"type","title":"ExAws.CodePipeline.action_name/0","doc":"The action declaration's name\n\n- Length Constraints: Minimum length of 1. Maximum length of 100.\n- Pattern: [A-Za-z0-9.@-_]+","ref":"ExAws.CodePipeline.html#t:action_name/0"},{"type":"type","title":"ExAws.CodePipeline.action_namespace/0","doc":"The variable namespace associated with the action\n\nAll variables produced as output by this action fall under this namespace.\n\n- Length Constraints: Minimum length of 1. Maximum length of 100.\n- Pattern: [A-Za-z0-9@-_]+","ref":"ExAws.CodePipeline.html#t:action_namespace/0"},{"type":"type","title":"ExAws.CodePipeline.action_owner/0","doc":"The creator of the action being called\n\nValid Values\n```\n[\"AWS\", \"ThirdParty\", \"Custom\"]\n```","ref":"ExAws.CodePipeline.html#t:action_owner/0"},{"type":"type","title":"ExAws.CodePipeline.action_owner_filter/0","doc":"Filters the list of action types to those created by a specified entity.\n\nValid Values\n```\n[\"AWS\", \"ThirdParty\", \"Custom\"]\n```","ref":"ExAws.CodePipeline.html#t:action_owner_filter/0"},{"type":"type","title":"ExAws.CodePipeline.action_provider/0","doc":"The provider of the service being called by the action\n\nValid providers are determined by the action category. For example, an action in the Deploy\ncategory type might have a provider of CodeDeploy, which would be specified as CodeDeploy.\n\n- Length Constraints: Minimum length of 1. Maximum length of 35.\n- Pattern: [0-9A-Za-z_-]+","ref":"ExAws.CodePipeline.html#t:action_provider/0"},{"type":"type","title":"ExAws.CodePipeline.action_revision/0","doc":"Represents information about the version (or revision) of an action\n\n- created - The date and time when the most recent version of the action was created, in timestamp\n  format.\n- revision_change_id - The unique identifier of the change that set the state to this revision\n  (for example, a deployment ID or timestamp)\n- revision_id - The system-generated unique ID that identifies the revision number of the action","ref":"ExAws.CodePipeline.html#t:action_revision/0"},{"type":"type","title":"ExAws.CodePipeline.action_timeout/0","doc":"A timeout duration in minutes that can be applied against the ActionType’s default timeout value\nspecified in Quotas for AWS CodePipeline.\n\nThis attribute is available only to the manual approval ActionType.\n\n- Valid Range: Minimum value of 5. Maximum value of 86400.","ref":"ExAws.CodePipeline.html#t:action_timeout/0"},{"type":"type","title":"ExAws.CodePipeline.action_type_id/0","doc":"Represents information about an action type. See [Valid Action Types and Providers in\nCodePipeline](https://docs.aws.amazon.com/codepipeline/latest/userguide/reference-pipeline-structure.html#actions-valid-providers).\n\n- category - A category defines what kind of action can be taken in the stage, and constrains the\n  provider type for the action\n- owner - The creator of the action being called\n- provider - The provider of the service being called by the action\n- version - A string that describes the action version","ref":"ExAws.CodePipeline.html#t:action_type_id/0"},{"type":"type","title":"ExAws.CodePipeline.action_type_owner/0","doc":"The creator of an action type that was created with any supported integration model\n\nValid Values\n```\n [\"AWS\", \"ThirdParty\"]\n```","ref":"ExAws.CodePipeline.html#t:action_type_owner/0"},{"type":"type","title":"ExAws.CodePipeline.action_type_setting/0","doc":"Information about the settings for an action type\n\n- entity_url_template - The URL returned to the CodePipeline console that provides a deep link to\n  the resources of the external system, such as the configuration page for a CodeDeploy deployment\n  group. This link is provided as part of the action display in the pipeline.\n- execution_url_template - The URL returned to the CodePipeline console that contains a link to\n  the top-level landing page for the external system, such as the console page for CodeDeploy.\n  This link is shown on the pipeline view page in the CodePipeline console and provides a link to\n  the execution entity of the external action.\n- revision_url_template - The URL returned to the CodePipeline console that contains a link to the\n  page where customers can update or change the configuration of the external action.\n- third_party_configuration_url - The URL of a sign-up page where users can sign up for an\n  external service and perform initial configuration of the action provided by that service.","ref":"ExAws.CodePipeline.html#t:action_type_setting/0"},{"type":"type","title":"ExAws.CodePipeline.allowed_IP_range/0","doc":"The property used to configure acceptance of webhooks in an IP address range\n\nFor IP, only the allowed_IP_range property must be set. This property must be set to a valid CIDR\nrange.\n\n- Length Constraints: Minimum length of 1. Maximum length of 100.","ref":"ExAws.CodePipeline.html#t:allowed_IP_range/0"},{"type":"type","title":"ExAws.CodePipeline.approval_result/0","doc":"Represents information about the result of an approval request","ref":"ExAws.CodePipeline.html#t:approval_result/0"},{"type":"type","title":"ExAws.CodePipeline.approval_result_status/0","doc":"The response submitted by a reviewer assigned to an approval action request\n\nValid Values\n```\n[\"Approved\" | \"Rejected\"]\n```","ref":"ExAws.CodePipeline.html#t:approval_result_status/0"},{"type":"type","title":"ExAws.CodePipeline.approval_result_summary/0","doc":"The summary of the current status of the approval request\n\n- Length Constraints: Minimum length of 0. Maximum length of 512.","ref":"ExAws.CodePipeline.html#t:approval_result_summary/0"},{"type":"type","title":"ExAws.CodePipeline.approval_token/0","doc":"The system-generated token used to identify a unique approval request.\n\nThe token for each open approval request can be obtained using the GetPipelineState action. It is\nused to validate that the approval request corresponding to this token is still valid.\n\n- Pattern: [0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}","ref":"ExAws.CodePipeline.html#t:approval_token/0"},{"type":"type","title":"ExAws.CodePipeline.artifact_details/0","doc":"Information about the details of an artifact\n\n- minimum_count - The minimum number of artifacts allowed for the action type.\n  Valid Range: Minimum value of 0. Maximum value of 5.\n- maximum_count -The maximum number of artifacts allowed for the action type.\n  Valid Range: Minimum value of 0. Maximum value of 5.","ref":"ExAws.CodePipeline.html#t:artifact_details/0"},{"type":"type","title":"ExAws.CodePipeline.artifact_name/0","doc":"The name of the output of an artifact, such as \"My App\".\n\nThe input artifact of an action must exactly match the output artifact declared in a preceding\naction, but the input artifact does not have to be the next action in strict sequence from the\naction that provided the output artifact. Actions in parallel can declare different output\nartifacts, which are in turn consumed by different following actions.\n\nOutput artifact names must be unique within a pipeline.\n\n- Length Constraints: Minimum length of 1. Maximum length of 100.\n- Pattern: [a-zA-Z0-9_-]+","ref":"ExAws.CodePipeline.html#t:artifact_name/0"},{"type":"type","title":"ExAws.CodePipeline.artifact_store/0","doc":"The S3 bucket where artifacts for the pipeline are stored.\n\n_Note: You must include either artifact_store or artifact_stores in your pipeline, but you cannot\nuse both. If you create a cross-region action in your pipeline, you must use artifact_stores_.\n\n- encryption_key - The encryption key used to encrypt the data in the artifact store, such as an\n  AWS Key Management Service key\n- location - The S3 bucket used for storing the artifacts for a pipeline\n- type - The type of the artifact store, such as S3","ref":"ExAws.CodePipeline.html#t:artifact_store/0"},{"type":"type","title":"ExAws.CodePipeline.artifact_store_location/0","doc":"The S3 bucket used for storing the artifacts for a pipeline\n\nYou can specify the name of an S3 bucket but not a folder in the bucket. A folder to contain the\npipeline artifacts is created for you based on the name of the pipeline. You can use any S3 bucket\nin the same AWS Region as the pipeline to store your pipeline artifacts.\n\n- Length Constraints: Minimum length of 3. Maximum length of 63.\n- Pattern: [a-zA-Z0-9-.]+","ref":"ExAws.CodePipeline.html#t:artifact_store_location/0"},{"type":"type","title":"ExAws.CodePipeline.artifact_store_type/0","doc":"The type of the artifact store, such as S3\n\nValid Values\n```\n[\"S3\"]\n```","ref":"ExAws.CodePipeline.html#t:artifact_store_type/0"},{"type":"type","title":"ExAws.CodePipeline.authentication/0","doc":"Defines the approach to authentication\n\nValid Values\n```\n[\"GITHUB_HMAC\", \"IP\", \"UNAUTHENTICATED\"]\n```","ref":"ExAws.CodePipeline.html#t:authentication/0"},{"type":"type","title":"ExAws.CodePipeline.authentication_configuration/0","doc":"Properties that configure the authentication applied to incoming webhook trigger requests.\n\nThe required properties depend on the authentication type. For GITHUB_HMAC, only the SecretToken\nproperty must be set. For IP, only the AllowedIPRange property must be set to a valid CIDR range.\nFor UNAUTHENTICATED, no properties can be set.\n\n- allowed_IP_range - The property used to configure acceptance of webhooks in an IP address range\n- secret_token - The property used to configure GitHub authentication","ref":"ExAws.CodePipeline.html#t:authentication_configuration/0"},{"type":"type","title":"ExAws.CodePipeline.aws_region_name/0","doc":"AWS Region, such as \"us-east-1\"\n\n- Length Constraints: Minimum length of 4. Maximum length of 30.","ref":"ExAws.CodePipeline.html#t:aws_region_name/0"},{"type":"type","title":"ExAws.CodePipeline.blocker_declaration/0","doc":"Reserved for future use\n\n- name - Reserved for future use\n- type - Reserved for future use","ref":"ExAws.CodePipeline.html#t:blocker_declaration/0"},{"type":"type","title":"ExAws.CodePipeline.blocker_name/0","doc":"Reserved for future use.\n\n- Length Constraints: Minimum length of 1. Maximum length of 100.","ref":"ExAws.CodePipeline.html#t:blocker_name/0"},{"type":"type","title":"ExAws.CodePipeline.blocker_type/0","doc":"Reserved for future use.\n\nValid Values\n```\n[\"Schedule\"]\n```","ref":"ExAws.CodePipeline.html#t:blocker_type/0"},{"type":"type","title":"ExAws.CodePipeline.category/0","doc":"The category of the custom action, such as a build action or a test action.","ref":"ExAws.CodePipeline.html#t:category/0"},{"type":"type","title":"Valid Values - ExAws.CodePipeline.category/0","doc":"```\n[\"Source\", \"Build\", \"Deploy\", \"Test\", \"Invoke\", \"Approval\"]\n```","ref":"ExAws.CodePipeline.html#t:category/0-valid-values"},{"type":"type","title":"ExAws.CodePipeline.change_identifier/0","doc":"The change identifier for the current revision\n\n- Length Constraints: Minimum length of 1. Maximum length of 100.","ref":"ExAws.CodePipeline.html#t:change_identifier/0"},{"type":"type","title":"ExAws.CodePipeline.client_request_token/0","doc":"The system-generated unique ID used to identify a unique execution request.\n\n- Length Constraints: Minimum length of 1. Maximum length of 128.\n- Pattern: ^[a-zA-Z0-9-]+$","ref":"ExAws.CodePipeline.html#t:client_request_token/0"},{"type":"type","title":"ExAws.CodePipeline.client_token/0","doc":"The clientToken portion of the clientId and clientToken pair used to verify that the calling\nentity is allowed access to the job and its details.\n\n- Length Constraints: Minimum length of 1. Maximum length of 256.","ref":"ExAws.CodePipeline.html#t:client_token/0"},{"type":"type","title":"ExAws.CodePipeline.condition_type/0","doc":"The type of condition to override for the stage, such as entry conditions, failure conditions, or\nsuccess conditions\n\nValid Values\n```\n[\"BEFORE_ENTRY\", \"ON_SUCCESS\"]\n```","ref":"ExAws.CodePipeline.html#t:condition_type/0"},{"type":"type","title":"ExAws.CodePipeline.continuation_token/0","doc":"A token generated by a job worker, such as a CodeDeploy deployment ID, that a successful job\nprovides to identify a partner action in progress.\n\nFuture jobs use this token to identify the running instance of the action. It can be reused to\nreturn more information about the progress of the partner action. When the action is complete, no\ncontinuation token should be supplied.\n\n- Length Constraints: Minimum length of 1. Maximum length of 2048.","ref":"ExAws.CodePipeline.html#t:continuation_token/0"},{"type":"type","title":"ExAws.CodePipeline.create_custom_action_type_optional/0","doc":"Optional input for function `create_custom_action_type/5` function\n\n- configuration_properties - The configuration properties for the custom action.\n- settings - URLs that provide users information about this custom action\n- tags - The tags for the custom action","ref":"ExAws.CodePipeline.html#t:create_custom_action_type_optional/0"},{"type":"type","title":"ExAws.CodePipeline.current_revision/0","doc":"Represents information about a current revision\n\n- change_identifier - The change identifier for the current revision.\n- revision - The revision ID of the current version of an artifact.\n- created - The date and time when the most recent revision of the artifact was created, in\n  timestamp format.\n- revision_summary - The summary of the most recent revision of the artifact.","ref":"ExAws.CodePipeline.html#t:current_revision/0"},{"type":"type","title":"ExAws.CodePipeline.description/0","doc":"The description of the action configuration property that is displayed to users.\n\n- Length Constraints: Minimum length of 1. Maximum length of 160.","ref":"ExAws.CodePipeline.html#t:description/0"},{"type":"type","title":"ExAws.CodePipeline.disabled_reason/0","doc":"The reason given to the user that a stage is disabled, such as waiting for manual approval or\nmanual tests\n\nThis message is displayed in the pipeline console UI.\n\n- Length Constraints: Minimum length of 1. Maximum length of 300.\n- Pattern: [a-zA-Z0-9!@ ().*?-]+","ref":"ExAws.CodePipeline.html#t:disabled_reason/0"},{"type":"type","title":"ExAws.CodePipeline.encryption_key/0","doc":"The encryption key used to encrypt the data in the artifact store, such as an AWS Key Management\nService key. If this is undefined, the default key for Amazon S3 is used.\n\n- type - The type of encryption key, such as an AWS KMS key\n- id - The ID used to identify the key","ref":"ExAws.CodePipeline.html#t:encryption_key/0"},{"type":"type","title":"ExAws.CodePipeline.encryption_key_id/0","doc":"The ID used to identify the key. For an AWS KMS key, you can use the key ID, the key ARN, or the\nalias ARN","ref":"ExAws.CodePipeline.html#t:encryption_key_id/0"},{"type":"type","title":"Notes - ExAws.CodePipeline.encryption_key_id/0","doc":"Aliases are recognized only in the account that created the AWS KMS key. For cross-account\nactions, you can only use the key ID or key ARN to identify the key. Cross-account actions involve\nusing the role from the other account (AccountB), so specifying the key ID will use the key from\nthe other account (AccountB).\n\n- Length Constraints: Minimum length of 1. Maximum length of 400.","ref":"ExAws.CodePipeline.html#t:encryption_key_id/0-notes"},{"type":"type","title":"ExAws.CodePipeline.encryption_key_type/0","doc":"The type of encryption key, such as an AWS KMS key.\n\nWhen creating or updating a pipeline, the value must be set to 'KMS'.","ref":"ExAws.CodePipeline.html#t:encryption_key_type/0"},{"type":"type","title":"ExAws.CodePipeline.execution_details/0","doc":"Optional input for function `put_job_success_result/2`\n\n- external_execution_id - The system-generated unique ID of this action used to identify this job\n  worker in any external systems, such as CodeDeploy.\n- percent_complete - The percentage of work completed on the action, represented on a scale of 0\n  to 100 percent.\n- summary - The summary of the current status of the actions","ref":"ExAws.CodePipeline.html#t:execution_details/0"},{"type":"type","title":"ExAws.CodePipeline.execution_id/0","doc":"The external ID of the run of the action that failed\n\n- Length Constraints: Minimum length of 1. Maximum length of 1500.","ref":"ExAws.CodePipeline.html#t:execution_id/0"},{"type":"type","title":"ExAws.CodePipeline.execution_mode/0","doc":"The method that the pipeline will use to handle multiple executions\n\nThe default mode is \"SUPERSEDED\".big\n\nValid Values\n```\n[\"QUEUED\", \"SUPERSEDED\", \"PARALLEL\"]\n```","ref":"ExAws.CodePipeline.html#t:execution_mode/0"},{"type":"type","title":"ExAws.CodePipeline.execution_summary/0","doc":"The summary of the current status of the actions.\n\n- Length Constraints: Minimum length of 1. Maximum length of 2048.","ref":"ExAws.CodePipeline.html#t:execution_summary/0"},{"type":"type","title":"ExAws.CodePipeline.failure_details/0","doc":"The details about the failure of a job\n\n- external_execution_id - The external ID of the run of the action that failed\n- message - The message about the failure\n- type - The type of the failure","ref":"ExAws.CodePipeline.html#t:failure_details/0"},{"type":"type","title":"ExAws.CodePipeline.failure_type/0","doc":"The type of the failure\n\nValid Values\n```\n[\"JobFailed\", \"ConfigurationError\", \"PermissionError\", \"RevisionOutOfSync\",\n\"RevisionUnavailable\", \"SystemUnavailable\"]\n```","ref":"ExAws.CodePipeline.html#t:failure_type/0"},{"type":"type","title":"ExAws.CodePipeline.get_pipeline_optional/0","doc":"Optional input for function `get_pipeline/2` function\n\n- version - The version number of the pipeline","ref":"ExAws.CodePipeline.html#t:get_pipeline_optional/0"},{"type":"type","title":"ExAws.CodePipeline.git_configuration/0","doc":"A type of trigger configuration for Git-based source actions","ref":"ExAws.CodePipeline.html#t:git_configuration/0"},{"type":"type","title":"Notes - ExAws.CodePipeline.git_configuration/0","doc":"- You can specify the Git configuration trigger type for all third-party Git-based source actions\n  that are supported by the \"CodeStarSourceConnection\" action type.","ref":"ExAws.CodePipeline.html#t:git_configuration/0-notes"},{"type":"type","title":"ExAws.CodePipeline.input_artifact/0","doc":"Represents information about the input of an action\n\n- name - The name of the output of an artifact, such as \"My App\".","ref":"ExAws.CodePipeline.html#t:input_artifact/0"},{"type":"type","title":"ExAws.CodePipeline.job_id/0","doc":"The unique system-generated ID of the job for which you want to confirm receipt.\n\n- Length Constraints: Minimum length of 1. Maximum length of 512.\n- Pattern: [0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}","ref":"ExAws.CodePipeline.html#t:job_id/0"},{"type":"type","title":"ExAws.CodePipeline.json_path/0","doc":"A JsonPath expression that is applied to the body/payload of the webhook\n\nThe value selected by the JsonPath expression must match the value specified in the MatchEquals\nfield. Otherwise, the request is ignored. For more information, see Java JsonPath implementation\nin GitHub.\n\n- Length Constraints: Minimum length of 1. Maximum length of 150.","ref":"ExAws.CodePipeline.html#t:json_path/0"},{"type":"type","title":"ExAws.CodePipeline.latest_in_pipeline_execution_filter/0","doc":"The field that specifies to filter on the latest execution in the pipeline","ref":"ExAws.CodePipeline.html#t:latest_in_pipeline_execution_filter/0"},{"type":"type","title":"Notes - ExAws.CodePipeline.latest_in_pipeline_execution_filter/0","doc":"Filtering on the latest execution is available for executions run on or after February 08, 2024.\n\n- pipeline_execution_id - The execution ID for the latest execution in the pipeline\n- start_time_range - The start time to filter on for the latest execution in the pipeline","ref":"ExAws.CodePipeline.html#t:latest_in_pipeline_execution_filter/0-notes"},{"type":"type","title":"ExAws.CodePipeline.list_action_executions_optional/0","doc":"Optional input for function `list_action_executions/2`\n\n- filter - Filter values for the action execution\n- max_results - The maximum number of results to return in a single call\n- next_token - The token that was returned from the previous `list_action_executions/2` call,\n  which can be used to return the next set of action executions in the list","ref":"ExAws.CodePipeline.html#t:list_action_executions_optional/0"},{"type":"type","title":"ExAws.CodePipeline.list_action_types_optional/0","doc":"Optional input for function `list_action_types/1`\n\n- action_owner_filter - Filters the list of action types to those created by a specified entity\n- next_token - An identifier that was returned from the previous list action types call, which can\n  be used to return the next set of action types in the list\n- region_filter - The Region to filter on for the list of action types","ref":"ExAws.CodePipeline.html#t:list_action_types_optional/0"},{"type":"type","title":"ExAws.CodePipeline.list_pipeline_executions_optional/0","doc":"Optional input for function `list_pipeline_executions/2`\n\n- filter - The pipeline execution to filter on. See `t:pipeline_execution_filter/0`.\n- next_token - The token that was returned from the previous `list_pipeline_executions/2` call, which\ncan be used to return the next set of pipeline executions in the list.\n- max_results - The maximum number of results to return in a single call","ref":"ExAws.CodePipeline.html#t:list_pipeline_executions_optional/0"},{"type":"type","title":"ExAws.CodePipeline.list_pipelines_optional/0","doc":"Optional input for function `list_pipelines/1`\n\n- next_token - An identifier that was returned from the previous list pipelines call. It can be\n  used to return the next set of pipelines in the list\n- max_results - The maximum number of results to return in a single call","ref":"ExAws.CodePipeline.html#t:list_pipelines_optional/0"},{"type":"type","title":"ExAws.CodePipeline.list_rule_executions_optional/0","doc":"Optional input for function `list_rule_executions/2`\n\n- filter - Input information used to filter rule execution history\n- max_results - The maximum number of results to return in a single call\n- next_token - The token that was returned from the previous `list_rule_executions/2` call, which\n  can be used to return the next set of rule executions in the list","ref":"ExAws.CodePipeline.html#t:list_rule_executions_optional/0"},{"type":"type","title":"ExAws.CodePipeline.list_rule_types_optional/0","doc":"Optional input for function `list_rule_types/1`\n\n- region_filter - The rule Region to filter on\n- rule_owner_filter - The rule owner to filter on","ref":"ExAws.CodePipeline.html#t:list_rule_types_optional/0"},{"type":"type","title":"ExAws.CodePipeline.list_tags_for_resource_optional/0","doc":"Optional input for function `list_tags_for_resource/2`\n\n- next_token - The token that was returned from the previous API call, which would be used to\n  return the next page of the list. Note. The `list_tags_for_resource/2` call lists all available\n  tags in one call and does not use pagination.\n- max_results - The maximum number of results to return in a single call","ref":"ExAws.CodePipeline.html#t:list_tags_for_resource_optional/0"},{"type":"type","title":"ExAws.CodePipeline.list_webhooks_optional/0","doc":"Optional input to for function `list_webhooks/1`\n\n- max_results - The maximum number of results to return in a single call\n- next_token - The token that was returned from the previous `list_webhooks/1` call, which can be\n  used to return the next set of webhooks in the list","ref":"ExAws.CodePipeline.html#t:list_webhooks_optional/0"},{"type":"type","title":"ExAws.CodePipeline.match_equals/0","doc":"The value selected by the JsonPath expression must match what is supplied in the MatchEquals\nfield.\n\nOtherwise, the request is ignored. Properties from the target action configuration can be included\nas placeholders in this value by surrounding the action configuration key with curly brackets. For\nexample, if the value supplied here is \"refs/heads/{Branch}\" and the target action has an action\nconfiguration property called \"Branch\" with a value of \"main\", the MatchEquals value is evaluated\nas \"refs/heads/main\".\n\n- Length Constraints: Minimum length of 1. Maximum length of 150.","ref":"ExAws.CodePipeline.html#t:match_equals/0"},{"type":"type","title":"ExAws.CodePipeline.max_batch_size/0","doc":"The maximum number of jobs to return in a poll for jobs call.\n\n- Valid Range: Minimum value of 1.","ref":"ExAws.CodePipeline.html#t:max_batch_size/0"},{"type":"type","title":"ExAws.CodePipeline.max_results/0","doc":"The maximum number of results to return in a single call","ref":"ExAws.CodePipeline.html#t:max_results/0"},{"type":"type","title":"Notes - ExAws.CodePipeline.max_results/0","doc":"To retrieve the remaining results, make another call with the returned nextToken value. Pipeline\nhistory is limited to the most recent 12 months, based on pipeline execution start times. Default\nvalue is 100.\n\n- Valid Range: Minimum value of 1. Maximum value of 1000.","ref":"ExAws.CodePipeline.html#t:max_results/0-notes"},{"type":"type","title":"ExAws.CodePipeline.message/0","doc":"The message about the failure\n\n- Length Constraints: Minimum length of 1. Maximum length of 5000.","ref":"ExAws.CodePipeline.html#t:message/0"},{"type":"type","title":"ExAws.CodePipeline.next_token/0","doc":"Used for paging. The next_token is returned by one function\ncall and must be passed into the next call to page.\n\n- Length Constraints: Minimum length of 1. Maximum length of 2048.","ref":"ExAws.CodePipeline.html#t:next_token/0"},{"type":"type","title":"ExAws.CodePipeline.nonce/0","doc":"A system-generated random number that CodePipeline uses to ensure that the job is being worked on\nby only one job worker\n\nGet this number from the response of the `poll_for_jobs/2` request that returned this job.\n\n- Length Constraints: Minimum length of 1. Maximum length of 50.","ref":"ExAws.CodePipeline.html#t:nonce/0"},{"type":"type","title":"ExAws.CodePipeline.output_artifact/0","doc":"Represents information about the output of an action\n\n- name - The name of the output of an artifact, such as \"My App\".","ref":"ExAws.CodePipeline.html#t:output_artifact/0"},{"type":"type","title":"ExAws.CodePipeline.output_variables/0","doc":"Key-value pairs produced as output by a job worker that can be made available\nto a downstream action configuration\n\nOutput variables is a String to string map.","ref":"ExAws.CodePipeline.html#t:output_variables/0"},{"type":"type","title":"ExAws.CodePipeline.output_variables_key/0","doc":"Key Pattern: [A-Za-z0-9@-_]+","ref":"ExAws.CodePipeline.html#t:output_variables_key/0"},{"type":"type","title":"ExAws.CodePipeline.output_variables_value/0","doc":"Value associated with the `t:output_variables_key/0` in output_variables\nin `t:put_job_success_result_optional/0`","ref":"ExAws.CodePipeline.html#t:output_variables_value/0"},{"type":"type","title":"ExAws.CodePipeline.percent_complete/0","doc":"The percentage of work completed on the action, represented on a scale of 0 to 100 percent.\n\n- Valid Range: Minimum value of 0. Maximum value of 100.","ref":"ExAws.CodePipeline.html#t:percent_complete/0"},{"type":"type","title":"ExAws.CodePipeline.pipeline_declaration/0","doc":"Represents the structure of actions and stages to be performed in the pipeline.\n\n- name - The name of the pipeline\n- roleArn - The Amazon Resource Name (ARN) for CodePipeline to use to either perform actions with\n  no actionRoleArn, or to use to assume roles for actions with an actionRoleArn.\n- stages - The stage in which to perform the action.\n- artifact_store - Represents information about the S3 bucket where artifacts are stored for the pipeline\n- artifact_stores - A mapping of artifactStore objects and their corresponding AWS Regions\n- execution_mode - The method that the pipeline will use to handle multiple executions\n- pipeline_type - Defines the pipeline type","ref":"ExAws.CodePipeline.html#t:pipeline_declaration/0"},{"type":"type","title":"ExAws.CodePipeline.pipeline_execution_filter/0","doc":"The pipeline execution to filter on\n\n- succeeded_in_stage - Filter for pipeline executions where the stage was successful in the\n  current pipeline version. See `t:succeeded_in_stage_filter/0`.","ref":"ExAws.CodePipeline.html#t:pipeline_execution_filter/0"},{"type":"type","title":"ExAws.CodePipeline.pipeline_execution_id/0","doc":"The id of a pipeline execution\n\n- Pattern: [0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}","ref":"ExAws.CodePipeline.html#t:pipeline_execution_id/0"},{"type":"type","title":"ExAws.CodePipeline.pipeline_name/0","doc":"The name of the pipeline\n\n- Length Constraints: Minimum length of 1. Maximum length of 100.\n- Pattern: [A-Za-z0-9.@-_]+","ref":"ExAws.CodePipeline.html#t:pipeline_name/0"},{"type":"type","title":"ExAws.CodePipeline.pipeline_trigger_declaration/0","doc":"Represents information about the specified trigger configuration, such as the filter criteria and\nthe source stage for the action that contains the trigger.","ref":"ExAws.CodePipeline.html#t:pipeline_trigger_declaration/0"},{"type":"type","title":"Notes - ExAws.CodePipeline.pipeline_trigger_declaration/0","doc":"- This is only supported for the CodeStarSourceConnection action type.\n- When a trigger configuration is specified, default change detection for repository and branch\n  commits is disabled.","ref":"ExAws.CodePipeline.html#t:pipeline_trigger_declaration/0-notes"},{"type":"type","title":"ExAws.CodePipeline.pipeline_type/0","doc":"CodePipeline provides the following pipeline types, which differ in characteristics and price, so\nthat you can tailor your pipeline features and cost to the needs of your applications.\n\n- V1 type pipelines have a JSON structure that contains standard pipeline, stage, and action-level\n  parameters.\n- V2 type pipelines have the same structure as a V1 type, along with additional parameters for\n  release safety and trigger configuration.","ref":"ExAws.CodePipeline.html#t:pipeline_type/0"},{"type":"type","title":"Important - ExAws.CodePipeline.pipeline_type/0","doc":"Including V2 parameters, such as triggers on Git tags, in the pipeline JSON when creating or\nupdating a pipeline will result in the pipeline having the V2 type of pipeline and the associated\ncosts.\n\nValue Values\n```\n[\"V1\", \"V2\"]\n```","ref":"ExAws.CodePipeline.html#t:pipeline_type/0-important"},{"type":"type","title":"ExAws.CodePipeline.pipeline_variable_declaration/0","doc":"A variable declared at the pipeline level\n\n- name - The name of a pipeline-level variable\n- default_value - The value of a pipeline-level variable\n- description - The description of a pipeline-level variable","ref":"ExAws.CodePipeline.html#t:pipeline_variable_declaration/0"},{"type":"type","title":"ExAws.CodePipeline.pipeline_variable_default_value/0","doc":"The value of a pipeline-level variable\n\n- Length Constraints: Minimum length of 1. Maximum length of 1000.\n- Pattern: .*","ref":"ExAws.CodePipeline.html#t:pipeline_variable_default_value/0"},{"type":"type","title":"ExAws.CodePipeline.pipeline_variable_description/0","doc":"The description of a pipeline-level variable\n\nIt's used to add additional context about the variable, and not being used at time when pipeline\nexecutes.\n\n- Length Constraints: Minimum length of 0. Maximum length of 200.\n- Pattern: .*","ref":"ExAws.CodePipeline.html#t:pipeline_variable_description/0"},{"type":"type","title":"ExAws.CodePipeline.pipeline_variable_name/0","doc":"The name of a pipeline-level variable\n\n- Length Constraints: Minimum length of 1. Maximum length of 128.\n- Pattern: [A-Za-z0-9@-_]+","ref":"ExAws.CodePipeline.html#t:pipeline_variable_name/0"},{"type":"type","title":"ExAws.CodePipeline.pipeline_version/0","doc":"The version number of the pipeline","ref":"ExAws.CodePipeline.html#t:pipeline_version/0"},{"type":"type","title":"Notes - ExAws.CodePipeline.pipeline_version/0","doc":"If you do not specify a version, defaults to the current version\n\n- Valid Range: Minimum value of 1.","ref":"ExAws.CodePipeline.html#t:pipeline_version/0-notes"},{"type":"type","title":"ExAws.CodePipeline.poll_for_jobs_optional/0","doc":"Optional input for function `poll_for_jobs/3`\n\n- max_batch_size - The maximum number of jobs to return in a poll for jobs call.\n- query_param - A map of property names and values.","ref":"ExAws.CodePipeline.html#t:poll_for_jobs_optional/0"},{"type":"type","title":"ExAws.CodePipeline.poll_for_third_party_jobs_optional/0","doc":"Optional input for function `poll_for_third_party_jobs/2`\n\n- max_batch_size - The maximum number of jobs to return in a poll for jobs call.","ref":"ExAws.CodePipeline.html#t:poll_for_third_party_jobs_optional/0"},{"type":"type","title":"ExAws.CodePipeline.provider/0","doc":"The provider of the service used in the custom action, such as CodeDeploy\n\n- Length Constraints: Minimum length of 1. Maximum length of 35.\n- Pattern: [0-9A-Za-z_-]+","ref":"ExAws.CodePipeline.html#t:provider/0"},{"type":"type","title":"ExAws.CodePipeline.provider_type/0","doc":"The source provider for the event, such as connections configured for a repository with Git tags,\nfor the specified trigger configuration.\n\nValid Values\n```\n[\"CodeStarSourceConnection\"]\n```","ref":"ExAws.CodePipeline.html#t:provider_type/0"},{"type":"type","title":"ExAws.CodePipeline.put_job_success_result_optional/0","doc":"Optional input for function `put_job_success_result/2`\n\n- execution_details - The execution details of the successful job, such as the actions taken by\nthe job worker.\n- current_revision - The ID of the current revision of the artifact successfully worked on by the\njob\n- continuation_token - A token generated by a job worker, such as a CodeDeploy deployment ID, that\na successful job provides to identify a custom action in progress.\n- output_variables - Key-value pairs produced as output by a job worker that can be made available\nto a downstream action configuration. output_variables can be included only when there is no\ncontinuation token on the request.","ref":"ExAws.CodePipeline.html#t:put_job_success_result_optional/0"},{"type":"type","title":"ExAws.CodePipeline.put_third_party_job_success_result_optional/0","doc":"Optional input for function `put_third_party_job_success_result/3`\n\n- continuation_token - A token generated by a job worker, such as a CodeDeploy deployment ID, that\na successful job provides to identify a partner action in progress\n- current_revision - Represents information about a current revision\n- execution_details - The details of the actions taken and results produced on an artifact as it\npasses through stages in the pipeline","ref":"ExAws.CodePipeline.html#t:put_third_party_job_success_result_optional/0"},{"type":"type","title":"ExAws.CodePipeline.query_param/0","doc":"A map of property names and values. For an action type with no queryable properties, this value\nmust be null or an empty map\n\nFor an action type with a queryable property, you must supply that property as a key in the map.\nOnly jobs whose action configuration matches the mapped value are returned.\n\n- Map Entries: Minimum number of 0 items. Maximum number of 1 item.\n- Key Length Constraints: Minimum length of 1. Maximum length of 50.\n- Value Length Constraints: Minimum length of 1. Maximum length of 50.\n- Value Pattern: [a-zA-Z0-9_-]+","ref":"ExAws.CodePipeline.html#t:query_param/0"},{"type":"type","title":"ExAws.CodePipeline.region_filter/0","doc":"Region to filter on for the list of action types\n\n- Length Constraints: Minimum length of 4. Maximum length of 30.","ref":"ExAws.CodePipeline.html#t:region_filter/0"},{"type":"type","title":"ExAws.CodePipeline.resource_arn/0","doc":"The Amazon Resource Name (ARN) of a resource\n\n- Pattern: arn:aws(-[w]+)*:codepipeline:.+:[0-9]{12}:.+","ref":"ExAws.CodePipeline.html#t:resource_arn/0"},{"type":"type","title":"ExAws.CodePipeline.revision_change_id/0","doc":"The unique identifier of the change that set the state to this revision (for example, a deployment\nID or timestamp).\n\n- Length Constraints: Minimum length of 1. Maximum length of 100.","ref":"ExAws.CodePipeline.html#t:revision_change_id/0"},{"type":"type","title":"ExAws.CodePipeline.revision_id/0","doc":"The system-generated unique ID that identifies the revision number of the action\n\n- Length Constraints: Minimum length of 1. Maximum length of 1500.","ref":"ExAws.CodePipeline.html#t:revision_id/0"},{"type":"type","title":"ExAws.CodePipeline.revision_summary/0","doc":"The summary of the most recent revision of the artifact.\n\n- Length Constraints: Minimum length of 1. Maximum length of 2048.","ref":"ExAws.CodePipeline.html#t:revision_summary/0"},{"type":"type","title":"ExAws.CodePipeline.role_arn/0","doc":"The Amazon Resource Name (ARN) for CodePipeline to use to either perform actions with\nno action_role_arn, or to use to assume roles for actions with an action_role_arn.\n\n- Length Constraints: Maximum length of 1024.\n- Pattern: arn:aws(-[w]+)*:iam::[0-9]{12}:role/.*","ref":"ExAws.CodePipeline.html#t:role_arn/0"},{"type":"type","title":"ExAws.CodePipeline.rule_execution_filter/0","doc":"Filter values for the rule execution","ref":"ExAws.CodePipeline.html#t:rule_execution_filter/0"},{"type":"type","title":"ExAws.CodePipeline.rule_owner_filter/0","doc":"The rule owner to filter on\n\nValid Values\n```\n[\"AWS\"]\n```","ref":"ExAws.CodePipeline.html#t:rule_owner_filter/0"},{"type":"type","title":"ExAws.CodePipeline.secret_token/0","doc":"The property used to configure GitHub authentication\n\nFor GITHUB_HMAC, only the SecretToken property must be set.","ref":"ExAws.CodePipeline.html#t:secret_token/0"},{"type":"type","title":"Important - ExAws.CodePipeline.secret_token/0","doc":"When creating CodePipeline webhooks, do not use your own credentials or reuse the same secret\ntoken across multiple webhooks. For optimal security, generate a unique secret token for each\nwebhook you create. The secret token is an arbitrary string that you provide, which GitHub uses to\ncompute and sign the webhook payloads sent to CodePipeline, for protecting the integrity and\nauthenticity of the webhook payloads. Using your own credentials or reusing the same token across\nmultiple webhooks can lead to security vulnerabilities.\n\n- Length Constraints: Minimum length of 1. Maximum length of 100.","ref":"ExAws.CodePipeline.html#t:secret_token/0-important"},{"type":"type","title":"ExAws.CodePipeline.stage_declaration/0","doc":"Represents information about a stage and its definition","ref":"ExAws.CodePipeline.html#t:stage_declaration/0"},{"type":"type","title":"ExAws.CodePipeline.stage_name/0","doc":"The name of the stage\n\n- Length Constraints: Minimum length of 1. Maximum length of 100.\n- Pattern: [A-Za-z0-9.@-_]+","ref":"ExAws.CodePipeline.html#t:stage_name/0"},{"type":"type","title":"ExAws.CodePipeline.start_pipeline_execution_optional/0","doc":"Optional input for function `start_pipeline_execution/2`\n\n- client_request_token - The system-generated unique ID used to identify a unique execution\nrequest.","ref":"ExAws.CodePipeline.html#t:start_pipeline_execution_optional/0"},{"type":"type","title":"ExAws.CodePipeline.start_time_range_filter/0","doc":"The start time to filter on for the latest execution in the pipeline\n\nValid Values\n```\n[\"Latest\", \"All\"]\n```","ref":"ExAws.CodePipeline.html#t:start_time_range_filter/0"},{"type":"type","title":"ExAws.CodePipeline.stop_pipeline_execution_optional/0","doc":"Optional input for function `stop_pipeline_execution/3`","ref":"ExAws.CodePipeline.html#t:stop_pipeline_execution_optional/0"},{"type":"type","title":"Notes - ExAws.CodePipeline.stop_pipeline_execution_optional/0","doc":"- abandon - Use this option to stop the pipeline execution by abandoning, rather than finishing,\n  in-progress actions. This option can lead to failed or out-of-sequence tasks.\n- reason - Use this option to enter comments, such as the reason the pipeline was stopped","ref":"ExAws.CodePipeline.html#t:stop_pipeline_execution_optional/0-notes"},{"type":"type","title":"ExAws.CodePipeline.stop_pipeline_execution_reason/0","doc":"Use this option to enter comments, such as the reason the pipeline was stopped\n\n- Length Constraints: Maximum length of 200.","ref":"ExAws.CodePipeline.html#t:stop_pipeline_execution_reason/0"},{"type":"type","title":"ExAws.CodePipeline.succeeded_in_stage_filter/0","doc":"Filter for pipeline executions that have successfully completed the stage in the current pipeline\nversion\n\n- Length Constraints: Minimum length of 1. Maximum length of 100.\n- Pattern: [A-Za-z0-9.@-_]+","ref":"ExAws.CodePipeline.html#t:succeeded_in_stage_filter/0"},{"type":"type","title":"ExAws.CodePipeline.tag/0","doc":"A tag is a key-value pair that is used to manage the resource.","ref":"ExAws.CodePipeline.html#t:tag/0"},{"type":"type","title":"ExAws.CodePipeline.tag_key/0","doc":"A `t:tag/0` key\n\n- Length Constraints: Minimum length of 1. Maximum length of 128.","ref":"ExAws.CodePipeline.html#t:tag_key/0"},{"type":"type","title":"ExAws.CodePipeline.tag_value/0","doc":"A `t:tag/0` value\n\n- Length Constraints: Minimum length of 1. Maximum length of 256.","ref":"ExAws.CodePipeline.html#t:tag_value/0"},{"type":"type","title":"ExAws.CodePipeline.target_action/0","doc":"The name of the action in a pipeline you want to connect to the webhook\n\nThe action must be from the source (first) stage of the pipeline.\n\n- Length Constraints: Minimum length of 1. Maximum length of 100.\n- Pattern: [A-Za-z0-9.@-_]+","ref":"ExAws.CodePipeline.html#t:target_action/0"},{"type":"type","title":"ExAws.CodePipeline.target_pipeline/0","doc":"The name of the pipeline you want to connect to the webhook\n\n- Length Constraints: Minimum length of 1. Maximum length of 100.\n- Pattern: [A-Za-z0-9.@-_]+","ref":"ExAws.CodePipeline.html#t:target_pipeline/0"},{"type":"type","title":"ExAws.CodePipeline.timestamp/0","doc":"Timestamps are formatted according to the ISO 8601 standard. These are often referred to as\n\"DateTime\" or \"Date\" parameters.\n\nAcceptable formats include:\n\n- YYYY-MM-DDThh:mm:ss.sssTZD (UTC), for example, 2014-10-01T20:30:00.000Z\n- YYYY-MM-DDThh:mm:ss.sssTZD (with offset), for example, 2014-10-01T12:30:00.000-08:00\n- YYYY-MM-DD, for example, 2014-10-01\n- Unix time in seconds, for example, 1412195400. This is sometimes referred to as Unix Epoch time\n  and represents the number of seconds since midnight, January 1, 1970 UTC.","ref":"ExAws.CodePipeline.html#t:timestamp/0"},{"type":"type","title":"ExAws.CodePipeline.transition_type/0","doc":"Specifies whether artifacts are prevented from transitioning into the stage and being processed by\nthe actions in that stage (inbound), or prevented from transitioning from the stage after they\nhave been processed by the actions in that stage (outbound).\n\nValid Values\n```\n[\"Inbound\", \"Outbound\"]\n```","ref":"ExAws.CodePipeline.html#t:transition_type/0"},{"type":"type","title":"ExAws.CodePipeline.update_action_type_optional/0","doc":"Optional input for function `update_action_type/6`\n\n- configuration_properties - The configuration properties for the custom action.\n- settings - URLs that provide users information about this custom action\n- tags - The tags for the custom action","ref":"ExAws.CodePipeline.html#t:update_action_type_optional/0"},{"type":"type","title":"ExAws.CodePipeline.url_template/0","doc":"URL used in `t:action_type_setting/0`\n\n- Length Constraints: Minimum length of 1. Maximum length of 2048.","ref":"ExAws.CodePipeline.html#t:url_template/0"},{"type":"type","title":"ExAws.CodePipeline.version/0","doc":"The version identifier of the custom action\n\n- Length Constraints: Minimum length of 1. Maximum length of 9.\n- Pattern: [0-9A-Za-z_-]+","ref":"ExAws.CodePipeline.html#t:version/0"},{"type":"type","title":"ExAws.CodePipeline.webhook_definition/0","doc":"Represents information about a webhook and its definition.\n\n- authentication - Supported options are \"GITHUB_HMAC\", \"IP\", and \"UNAUTHENTICATED\"\n- authentication_configuration - Properties that configure the authentication applied to incoming\n  webhook trigger requests\n- filters - A list of rules applied to the body/payload sent in the POST request to a webhook URL\n- name - The name of the webhook\n- target_action - The name of the action in a pipeline you want to connect to the webhook\n- target_pipeline - The name of the pipeline you want to connect to the webhook","ref":"ExAws.CodePipeline.html#t:webhook_definition/0"},{"type":"type","title":"ExAws.CodePipeline.webhook_filter_rule/0","doc":"The event criteria that specify when a webhook notification is sent to your URL\n\n- json_path - A JSONPath expression (JSONPath is a query language for JSON, similar to XPath for\n  XML. It allows you to select and extract data from a JSON document) that is applied to the\n  body/payload of the webhook\n- match_equals - The value selected by the JsonPath expression must match what is supplied in the\n  MatchEquals field.","ref":"ExAws.CodePipeline.html#t:webhook_filter_rule/0"},{"type":"type","title":"ExAws.CodePipeline.webhook_name/0","doc":"The name of a webhook\n\n- Length Constraints: Minimum length of 1. Maximum length of 100.\n- Pattern: [A-Za-z0-9.@-_]+","ref":"ExAws.CodePipeline.html#t:webhook_name/0"},{"type":"module","title":"ExAws.CodePipeline.Utils","doc":"Helper utility functions","ref":"ExAws.CodePipeline.Utils.html"},{"type":"function","title":"ExAws.CodePipeline.Utils.camelize/2","doc":"Camelize an atom or string value\n\nThis works as expected if the val uses an underscore or\nhyphen to separate words. This only works for atoms and\nstrings. Passing another value type (integer, list, map)\nwill raise exception.\n\nThe regex used to split a String into words is: `~r/(?:^|[-_])|(?=[A-Z])/`","ref":"ExAws.CodePipeline.Utils.html#camelize/2"},{"type":"function","title":"Example - ExAws.CodePipeline.Utils.camelize/2","doc":"iex> ExAws.CodePipeline.Utils.camelize(:test_val)\n    \"testVal\"\n\n    iex> ExAws.CodePipeline.Utils.camelize(:\"test_val\")\n    \"testVal\"\n\n    iex> ExAws.CodePipeline.Utils.camelize(:\"abc-def-a123\")\n    \"abcDefA123\"\n\n    iex> ExAws.CodePipeline.Utils.camelize(:A_test_of_initial_cap)\n    \"aTestOfInitialCap\"","ref":"ExAws.CodePipeline.Utils.html#camelize/2-example"},{"type":"function","title":"ExAws.CodePipeline.Utils.camelize_map/2","doc":"Camelize keys, including traversing values that are also Maps.\n\nThe caller can pass in an argument to indicate whether the first letter of a key for the map are\ndowncased or capitalized.\n\nKeys should be atoms and follow the rules listed for the `camelize/2` function.","ref":"ExAws.CodePipeline.Utils.html#camelize_map/2"},{"type":"function","title":"Example - ExAws.CodePipeline.Utils.camelize_map/2","doc":"iex> val = %{abc_def: 123, another_val: \"val2\"}\n    iex> ExAws.CodePipeline.Utils.camelize_map(val)\n    %{\"abcDef\" => 123, \"anotherVal\" => \"val2\"}\n\n    iex> val = %{abc_def: 123, another_val: %{embed_value: \"val2\"}}\n    iex> ExAws.CodePipeline.Utils.camelize_map(val)\n    %{\"abcDef\" => 123, \"anotherVal\" => %{\"embedValue\" => \"val2\"}}\n\n    iex> val = %{abc_def: 123, another_val: %{embed_value: \"val2\"}}\n    iex> ExAws.CodePipeline.Utils.camelize_map(val, %{subkeys: %{}, keys: %{}, default: :upper})\n    %{\"AbcDef\" => 123, \"AnotherVal\" => %{\"EmbedValue\" => \"val2\"}}","ref":"ExAws.CodePipeline.Utils.html#camelize_map/2-example"},{"type":"function","title":"ExAws.CodePipeline.Utils.camelize_rules/0","doc":"Return the default camelize rules\n\nA caller can override this by creating a `t:camelize_rules/0` and passing\nit into functions instead of the default.","ref":"ExAws.CodePipeline.Utils.html#camelize_rules/0"},{"type":"function","title":"ExAws.CodePipeline.Utils.keyword_to_map/1","doc":"If val is a Keyword then convert to a Map, else return val.\n\nThis function works recursively. If you have a Keyword list where\nthe value for the key is a keyword then the val is converted to\na Map as well.","ref":"ExAws.CodePipeline.Utils.html#keyword_to_map/1"},{"type":"function","title":"Examples - ExAws.CodePipeline.Utils.keyword_to_map/1","doc":"iex> ExAws.CodePipeline.Utils.keyword_to_map([{:a, 7}, {:b, \"abc\"}])\n    %{a: 7, b: \"abc\"}\n\n    iex> ExAws.CodePipeline.Utils.keyword_to_map(%{a: 7, b: %{c: \"abc\"}})\n    %{a: 7, b: %{c: \"abc\"}}\n\n    iex> ExAws.CodePipeline.Utils.keyword_to_map([1, 2, 3])\n    [1, 2, 3]\n\n    iex> ExAws.CodePipeline.Utils.keyword_to_map[test: [inner: \"abc\"]]\n    %{test: %{inner: \"abc\"}}","ref":"ExAws.CodePipeline.Utils.html#keyword_to_map/1-examples"},{"type":"function","title":"ExAws.CodePipeline.Utils.string_camelize/2","doc":"","ref":"ExAws.CodePipeline.Utils.html#string_camelize/2"},{"type":"type","title":"ExAws.CodePipeline.Utils.camelization/0","doc":"Approach to camelization\n\n- upper - all words are upper-cased\n- lower - the first word is lower cased and the remaining words are upper-cased","ref":"ExAws.CodePipeline.Utils.html#t:camelization/0"},{"type":"type","title":"Examples - ExAws.CodePipeline.Utils.camelization/0","doc":"<!-- tabs-open -->\n\n### :upper\n\n```\niex> camelize_rules = %{default: :upper}\niex> ExAws.CodePipeline.Utils.camelize(:test_things, camelize_rules)\n\"TestThings\"\n\niex> camelize_rules = %{default: :upper}\niex> ExAws.CodePipeline.Utils.camelize(:abc, camelize_rules)\n\"Abc\"\n\niex> camelize_rules = %{default: :upper}\niex> ExAws.CodePipeline.Utils.camelize(\"test-a-string\", camelize_rules)\n\"TestAString\"\n```\n\n### :lower\n\n```\niex> camelize_rules = %{default: :lower}\niex> ExAws.CodePipeline.Utils.camelize(:test_things, camelize_rules)\n\"testThings\"\n\niex> camelize_rules = %{default: :lower}\niex> ExAws.CodePipeline.Utils.camelize(:abc, camelize_rules)\n\"abc\"\n\niex> camelize_rules = %{default: :lower}\niex> ExAws.CodePipeline.Utils.camelize(\"test-a-string\", camelize_rules)\n\"testAString\"\n```\n<!-- tabs-close -->","ref":"ExAws.CodePipeline.Utils.html#t:camelization/0-examples"},{"type":"type","title":"ExAws.CodePipeline.Utils.camelize_rules/0","doc":"The camelize, camelize_list, and camelize_map take an argument that is\na data structure providing rules for capitalization.\n\n- subkeys - this provides a map that indicates how keys found under this\n  particular key should be camelized\n- keys - this provides a map that indicate how particular keys should be\n  camelized\n- default - indicates whether `:upper` or `:lower` is used by default","ref":"ExAws.CodePipeline.Utils.html#t:camelize_rules/0"},{"type":"extras","title":"AWS CodePipeline API","doc":"# AWS CodePipeline API\n\nAWS Code Pipeline Service module for [ex_aws](https://github.com/ex-aws/ex_aws).","ref":"readme.html"},{"type":"extras","title":"Installation - AWS CodePipeline API","doc":"The package can be installed by adding ex_aws_code_pipeline to your list of dependencies in mix.exs along with :ex_aws and your preferred JSON codec / http client. Example:\n\n```elixir\ndef deps do\n  [\n    {:ex_aws, \"~> 2.0\"},\n    {:ex_aws_code_pipeline, \"~> 2.1\"},\n    {:poison, \"~> 3.0\"},\n    {:hackney, \"~> 1.9\"},\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Documentation - AWS CodePipeline API","doc":"* [ex_aws](https://hexdocs.pm/ex_aws)\n* [AWS CodePipeline API](https://docs.aws.amazon.com/codepipeline/latest/APIReference/Welcome.html)\n* [Go API for CodePipeline](https://github.com/aws/aws-sdk-go/blob/master/models/apis/codepipeline/2015-07-09/api-2.json)","ref":"readme.html#documentation"},{"type":"extras","title":"License - AWS CodePipeline API","doc":"[License](LICENSE)","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"v2.1.0\n------\n#### Enhancements\n  - Use Github Workflows to test with multiple Elixir versions, credo, dialyzer\n  - Update dependencies\n  - Provide types that allow either Keyword lists or Map to be passed for optional\n    data for API functions.\n  - Fill in missing API functions","ref":"changelog.html"},{"type":"extras","title":"License","doc":"MIT License\n\nCopyright (c) 2018 Vonage, Inc.\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}